(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[    115978,       2755]
NotebookOptionsPosition[    112718,       2643]
NotebookOutlinePosition[    113053,       2658]
CellTagsIndexPosition[    113010,       2655]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Gravito-scalar QNMs of Schwarzschild BHs in Dynamical Chern-Simons gravity\n\
",
 StyleBox["Reference: Paolo Pani, \[OpenCurlyDoubleQuote]Advanced methods in \
Black-Hole Perturbation Theory\[CloseCurlyDoubleQuote] (2013)",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{
  3.5701092341113586`*^9, {3.570117652780466*^9, 3.5701176573116493`*^9}, {
   3.570118625235464*^9, 3.5701186769267683`*^9}, {3.570227375137948*^9, 
   3.570227401005803*^9}}],

Cell[CellGroupData[{

Cell["Perturbation equations:", "Subsubsection",
 CellChangeTimes->{{3.541511504872143*^9, 3.541511505640195*^9}, {
  3.5702274079329967`*^9, 3.5702274110512743`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"u1", ",", "u2"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Epsilon]a", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "r_", "]"}], ":=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     RowBox[{"M", "/", "r"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V1", "=", 
   RowBox[{
    RowBox[{"F", "[", "r", "]"}], 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"l", 
        RowBox[{"(", 
         RowBox[{"l", "+", "1"}], ")"}]}], 
       SuperscriptBox["r", "2"]], "-", 
      FractionBox[
       RowBox[{"6", "M"}], 
       SuperscriptBox["r", "3"]]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"V2", "=", 
   RowBox[{
    RowBox[{"F", "[", "r", "]"}], 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       FractionBox[
        RowBox[{"l", 
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}]}], 
        SuperscriptBox["r", "2"]], 
       RowBox[{"(", 
        RowBox[{"1", "+", 
         FractionBox[
          RowBox[{"576", " ", "\[Pi]", " ", 
           SuperscriptBox["M", "2"], 
           SuperscriptBox["\[Alpha]", "2"]}], 
          RowBox[{"\[Beta]", " ", 
           SuperscriptBox["r", "6"]}]]}], ")"}]}], "+", 
      FractionBox[
       RowBox[{"2", "M"}], 
       SuperscriptBox["r", "3"]]}], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S1", "=", 
   RowBox[{
    RowBox[{"F", "[", "r", "]"}], 
    RowBox[{"(", 
     FractionBox[
      RowBox[{
      "96", " ", "I", " ", "\[Pi]", " ", "M", " ", "\[Omega]", " ", 
       "\[Alpha]"}], 
      SuperscriptBox["r", "5"]], ")"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"S2", "=", 
   RowBox[{
    RowBox[{"F", "[", "r", "]"}], 
    RowBox[{"(", 
     RowBox[{
      FractionBox[
       RowBox[{"Factorial", "[", 
        RowBox[{"l", "+", "2"}], "]"}], 
       RowBox[{"Factorial", "[", 
        RowBox[{"l", "-", "2"}], "]"}]], 
      FractionBox[
       RowBox[{"6", " ", "M", " ", "I", " ", "\[Alpha]"}], 
       RowBox[{"\[Beta]", " ", 
        SuperscriptBox["r", "5"], "\[Omega]"}]]}], ")"}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"e1", "=", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"F", "[", "r", "]"}], "2"], 
    RowBox[{
     RowBox[{"u1", "''"}], "[", "r", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "'"}], "[", "r", "]"}], 
    RowBox[{"F", "[", "r", "]"}], 
    RowBox[{
     RowBox[{"u1", "'"}], "[", "r", "]"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Omega]", "2"], "-", "V1"}], ")"}], 
    RowBox[{"u1", "[", "r", "]"}]}], "-", 
   RowBox[{"S1", " ", 
    RowBox[{"u2", "[", "r", "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{"e2", "=", 
  RowBox[{
   RowBox[{
    SuperscriptBox[
     RowBox[{"F", "[", "r", "]"}], "2"], 
    RowBox[{
     RowBox[{"u2", "''"}], "[", "r", "]"}]}], "+", 
   RowBox[{
    RowBox[{
     RowBox[{"F", "'"}], "[", "r", "]"}], 
    RowBox[{"F", "[", "r", "]"}], 
    RowBox[{
     RowBox[{"u2", "'"}], "[", "r", "]"}]}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[Omega]", "2"], "-", "V2"}], ")"}], 
    RowBox[{"u2", "[", "r", "]"}]}], "-", 
   RowBox[{"S2", " ", 
    RowBox[{"u1", "[", "r", "]"}]}]}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.540637778227034*^9, 3.5406378117383137`*^9}, 
   3.540638363388339*^9, {3.540639186931592*^9, 3.540639206822613*^9}, {
   3.5406411677281227`*^9, 3.540641169929409*^9}, {3.5411601900551033`*^9, 
   3.541160191461273*^9}, {3.570222846090981*^9, 3.570222847031705*^9}, {
   3.5702228825538054`*^9, 3.570222896135741*^9}, {3.570222936532469*^9, 
   3.5702229979407787`*^9}, {3.570223503343112*^9, 3.570223504275032*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"6", " ", "M"}], 
           SuperscriptBox["r", "3"]]}], "+", 
         FractionBox[
          RowBox[{"l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}]}], 
          SuperscriptBox["r", "2"]]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        FractionBox[
         RowBox[{"2", " ", "M"}], "r"]}], ")"}]}], "+", 
     SuperscriptBox["\[Omega]", "2"]}], ")"}], " ", 
   RowBox[{"u1", "[", "r", "]"}]}], "-", 
  FractionBox[
   RowBox[{"96", " ", "\[ImaginaryI]", " ", "M", " ", "\[Pi]", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", "\[Alpha]", " ", 
    "\[Omega]", " ", 
    RowBox[{"u2", "[", "r", "]"}]}], 
   SuperscriptBox["r", "5"]], "+", 
  FractionBox[
   RowBox[{"2", " ", "M", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["u1", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   SuperscriptBox["r", "2"]], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "M"}], "r"]}], ")"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["u1", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5702235045467443`*^9, 3.5702328766397657`*^9, 
  3.570233718923354*^9, 3.570234070350959*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", "\[ImaginaryI]", " ", "M", " ", 
     RowBox[{"(", 
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", "\[Alpha]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"2", "+", "l"}], ")"}], "!"}], " ", 
     RowBox[{"u1", "[", "r", "]"}]}], 
    RowBox[{
     SuperscriptBox["r", "5"], " ", "\[Beta]", " ", "\[Omega]", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "2"}], "+", "l"}], ")"}], "!"}]}]]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         FractionBox[
          RowBox[{"2", " ", "M"}], "r"]}], ")"}]}], " ", 
      RowBox[{"(", 
       RowBox[{
        FractionBox[
         RowBox[{"2", " ", "M"}], 
         SuperscriptBox["r", "3"]], "+", 
        FractionBox[
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", 
            FractionBox[
             RowBox[{"576", " ", 
              SuperscriptBox["M", "2"], " ", "\[Pi]", " ", 
              SuperscriptBox["\[Alpha]", "2"]}], 
             RowBox[{
              SuperscriptBox["r", "6"], " ", "\[Beta]"}]]}], ")"}]}], 
         SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
     SuperscriptBox["\[Omega]", "2"]}], ")"}], " ", 
   RowBox[{"u2", "[", "r", "]"}]}], "+", 
  FractionBox[
   RowBox[{"2", " ", "M", " ", 
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", 
    RowBox[{
     SuperscriptBox["u2", "\[Prime]",
      MultilineFunction->None], "[", "r", "]"}]}], 
   SuperscriptBox["r", "2"]], "+", 
  RowBox[{
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"1", "-", 
      FractionBox[
       RowBox[{"2", " ", "M"}], "r"]}], ")"}], "2"], " ", 
   RowBox[{
    SuperscriptBox["u2", "\[Prime]\[Prime]",
     MultilineFunction->None], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{3.5702235045467443`*^9, 3.5702328766397657`*^9, 
  3.570233718923354*^9, 3.5702340703545856`*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Series at the horizon [arbitrary order]\
\>", "Subsubsection",
 CellChangeTimes->{{3.540637974481348*^9, 3.540637979027294*^9}, {
  3.541240379828671*^9, 3.541240380708263*^9}, {3.570227435623144*^9, 
  3.570227459275071*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Clear", "[", 
    RowBox[{"u1", ",", "u2"}], "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u1", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"r", "-", 
       RowBox[{"2", "M"}]}], ")"}], "bb"], 
    RowBox[{"G1", "[", "r", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u2", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"r", "-", 
       RowBox[{"2", "M"}]}], ")"}], "bb"], 
    RowBox[{"G2", "[", "r", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es1", "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox[
     RowBox[{
      SuperscriptBox["r", "6"], "e1"}], 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "bb"]], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Es2", "=", 
   RowBox[{"FullSimplify", "[", 
    FractionBox["e2", 
     RowBox[{
      FractionBox["1", 
       RowBox[{
        SuperscriptBox["r", "9"], " ", "\[Beta]", " ", "\[Omega]", " ", 
        RowBox[{"Gamma", "[", 
         RowBox[{
          RowBox[{"-", "1"}], "+", "l"}], "]"}]}]], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "bb"]}]], 
    "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.540638101602265*^9, 3.540638172294088*^9}, {
   3.540638389057453*^9, 3.540638420643221*^9}, {3.540638476461603*^9, 
   3.540638484535878*^9}, {3.540641173192712*^9, 3.540641176330649*^9}, {
   3.54116048571681*^9, 3.5411604993744907`*^9}, 3.541161025380921*^9, 
   3.541161823369906*^9, {3.570223240566702*^9, 3.5702232882070227`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ORD", "=", "5"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"G1", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"u1h", "[", "i", "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", "M"}]}], ")"}], "i"]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"ORD", "+", "3"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"G2", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"u2h", "[", "i", "]"}], 
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"r", "-", 
         RowBox[{"2", "M"}]}], ")"}], "i"]}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"ORD", "+", "3"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ss", "=", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Es1", ",", "Es2"}], "}"}], "/.", 
      RowBox[{"{", 
       RowBox[{"bb", "\[Rule]", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "M", " ", 
         "\[Omega]"}]}], "}"}]}], ",", 
     RowBox[{"{", 
      RowBox[{"r", ",", 
       RowBox[{"2", "M"}], ",", 
       RowBox[{"ORD", "+", "3"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yh", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"u1h", "[", "i", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "ORD"}], "}"}]}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"u2h", "[", "i", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "ORD"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQsh", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"SeriesCoefficient", "[", 
            RowBox[{
             RowBox[{"ss", "[", 
              RowBox[{"[", "1", "]"}], "]"}], ",", "i"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"J", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
        "\[Equal]", "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "ORD"}], "}"}]}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Normal", "[", 
         RowBox[{"Series", "[", 
          RowBox[{
           RowBox[{"SeriesCoefficient", "[", 
            RowBox[{
             RowBox[{"ss", "[", 
              RowBox[{"[", "2", "]"}], "]"}], ",", "i"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"J", ",", "0", ",", "1"}], "}"}]}], "]"}], "]"}], 
        "\[Equal]", "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "ORD"}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "yh", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "EQsh", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"seriesH", "=", 
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"EQsh", ",", "yh"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{"u1", ",", "u2", ",", "G1", ",", "G2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.5406381747719183`*^9, 3.540638214902981*^9}, {
   3.540638253430633*^9, 3.540638264662983*^9}, {3.540638429710978*^9, 
   3.540638433225618*^9}, {3.540638503416449*^9, 3.540638700054585*^9}, {
   3.540638745877946*^9, 3.540638830003422*^9}, 3.5406411967221413`*^9, {
   3.540641276112341*^9, 3.540641278470973*^9}, {3.540642949788501*^9, 
   3.54064294990764*^9}, {3.540643620657374*^9, 3.540643636095202*^9}, 
   3.540643703884862*^9, {3.54116046010569*^9, 3.541160472236966*^9}, {
   3.541160519553906*^9, 3.541160541763425*^9}, 3.541160877406829*^9, {
   3.541160925912322*^9, 3.541160931523781*^9}, {3.541161005479727*^9, 
   3.5411610193400297`*^9}, {3.541161830265255*^9, 3.5411618595886374`*^9}, {
   3.541233309728834*^9, 3.541233321030945*^9}, 3.546155727791862*^9, 
   3.546155833588764*^9, 3.546247707013624*^9, 3.546248037420553*^9, 
   3.546248219746612*^9, {3.570223295118734*^9, 3.570223344068103*^9}, {
   3.570223408743801*^9, 3.570223453098844*^9}}],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{{3.540638658086236*^9, 3.540638693410458*^9}, {
   3.540638766544732*^9, 3.540638831254327*^9}, 3.540641204190351*^9, 
   3.540641281798015*^9, 3.540641328523964*^9, 3.5406429817052402`*^9, {
   3.540643632339657*^9, 3.540643638984193*^9}, 3.540643708183689*^9, 
   3.5406448791697187`*^9, 3.540644999054545*^9, 3.541160543888485*^9, 
   3.5411608822550993`*^9, 3.541160932094862*^9, 3.541161038398465*^9, 
   3.5411618616830482`*^9, {3.541233299519392*^9, 3.5412333224826393`*^9}, 
   3.543845877110413*^9, 3.545225946863161*^9, 3.546155735157024*^9, 
   3.546155834423011*^9, 3.546247727278943*^9, 3.546248039879912*^9, 
   3.546248221239696*^9, 3.547111179427931*^9, {3.5702233163574*^9, 
   3.570223345952386*^9}, {3.570223409099103*^9, 3.570223413090708*^9}, {
   3.570223446956991*^9, 3.5702234534917192`*^9}, 3.570232883680064*^9, 
   3.570233724464576*^9, 3.570234078581484*^9}],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{{3.540638658086236*^9, 3.540638693410458*^9}, {
   3.540638766544732*^9, 3.540638831254327*^9}, 3.540641204190351*^9, 
   3.540641281798015*^9, 3.540641328523964*^9, 3.5406429817052402`*^9, {
   3.540643632339657*^9, 3.540643638984193*^9}, 3.540643708183689*^9, 
   3.5406448791697187`*^9, 3.540644999054545*^9, 3.541160543888485*^9, 
   3.5411608822550993`*^9, 3.541160932094862*^9, 3.541161038398465*^9, 
   3.5411618616830482`*^9, {3.541233299519392*^9, 3.5412333224826393`*^9}, 
   3.543845877110413*^9, 3.545225946863161*^9, 3.546155735157024*^9, 
   3.546155834423011*^9, 3.546247727278943*^9, 3.546248039879912*^9, 
   3.546248221239696*^9, 3.547111179427931*^9, {3.5702233163574*^9, 
   3.570223345952386*^9}, {3.570223409099103*^9, 3.570223413090708*^9}, {
   3.570223446956991*^9, 3.5702234534917192`*^9}, 3.570232883680064*^9, 
   3.570233724464576*^9, 3.570234078582045*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Solve", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
      SuperscriptBox["bb", "2"], " ", 
      SuperscriptBox["M", "2"]}], "+", 
     RowBox[{"4", " ", 
      SuperscriptBox["M", "4"], " ", 
      SuperscriptBox["\[Omega]", "2"]}]}], "\[Equal]", "0"}], ",", "bb"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.5702234158140173`*^9, 3.570223423360921*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"bb", "\[Rule]", 
     RowBox[{
      RowBox[{"-", "2"}], " ", "\[ImaginaryI]", " ", "M", " ", "\[Omega]"}]}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"bb", "\[Rule]", 
     RowBox[{"2", " ", "\[ImaginaryI]", " ", "M", " ", "\[Omega]"}]}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5702234162163973`*^9, 3.570223423720213*^9}, 
   3.570232885595642*^9, 3.5702337264113073`*^9, 3.570234080431336*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"DumpSave", "[", 
    RowBox[{"\"\<seriesH.mx\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"seriesH", ",", "ORD"}], "}"}]}], "]"}], ";"}], "*)"}]], "Input",\

 CellChangeTimes->{{3.5406429600368223`*^9, 3.540642995847229*^9}, {
   3.540644642473556*^9, 3.540644643473922*^9}, {3.54064499440212*^9, 
   3.540644997444906*^9}, 3.57022335045984*^9, {3.570223388103956*^9, 
   3.570223388230588*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Series at infinity [arbitrary order]\
\>", "Subsubsection",
 CellChangeTimes->{{3.5412403856042643`*^9, 3.541240388196097*^9}, {
  3.570227424462688*^9, 3.570227451198436*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"u1", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{"kk", " ", "r"}], "]"}], 
    SuperscriptBox["r", "n"], 
    RowBox[{"G1", "[", "r", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"u2", "[", "r_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Exp", "[", 
     RowBox[{"kk", " ", "r"}], "]"}], 
    SuperscriptBox["r", "n"], 
    RowBox[{"G2", "[", "r", "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Es1", "=", 
  RowBox[{"FullSimplify", "[", 
   FractionBox["e1", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"kk", " ", "r"}]], " ", 
     SuperscriptBox["r", "n"], " "}]], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Es2", "=", 
  RowBox[{"FullSimplify", "[", 
   FractionBox["e2", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{"kk", " ", "r"}]], " ", 
     SuperscriptBox["r", "n"], " "}]], "]"}]}]}], "Input",
 CellChangeTimes->{{3.541240395475844*^9, 3.541240437765283*^9}, {
  3.5412406696491823`*^9, 3.541240696163704*^9}, {3.541240738142997*^9, 
  3.541240761194076*^9}, {3.541240820573422*^9, 3.541240828205003*^9}, {
  3.570223018656796*^9, 3.570223034720335*^9}, {3.570223085466899*^9, 
  3.570223089638712*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   SuperscriptBox["r", "6"]], 
  RowBox[{"(", 
   RowBox[{
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], " ", "M", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", "n"}], ")"}], " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "n"}], ")"}]}], "-", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"l", "+", 
             SuperscriptBox["l", "2"], "-", 
             RowBox[{"2", " ", "kk", " ", "M"}], "+", "n", "+", 
             RowBox[{"4", " ", "kk", " ", "M", " ", "n"}], "-", 
             SuperscriptBox["n", "2"]}], ")"}], " ", "r"}], "+", 
          RowBox[{"2", " ", "kk", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "kk"}], " ", "M"}], "+", "n"}], ")"}], " ", 
           SuperscriptBox["r", "2"]}], "+", 
          RowBox[{
           SuperscriptBox["kk", "2"], " ", 
           SuperscriptBox["r", "3"]}]}], ")"}]}], "+", 
       RowBox[{
        SuperscriptBox["r", "4"], " ", 
        SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
     RowBox[{"G1", "[", "r", "]"}]}], "+", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
       "96", " ", "\[ImaginaryI]", " ", "M", " ", "\[Pi]", " ", "\[Alpha]", 
        " ", "\[Omega]", " ", 
        RowBox[{"G2", "[", "r", "]"}]}], "-", 
       RowBox[{
        SuperscriptBox["r", "3"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"M", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                RowBox[{"2", " ", "n"}], "-", 
                RowBox[{"2", " ", "kk", " ", "r"}]}], ")"}]}], "+", 
             RowBox[{"r", " ", 
              RowBox[{"(", 
               RowBox[{"n", "+", 
                RowBox[{"kk", " ", "r"}]}], ")"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["G1", "\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}], "+", 
          RowBox[{"r", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["G1", "\[Prime]\[Prime]",
             MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
      ")"}]}]}], ")"}]}]], "Output",
 CellChangeTimes->{{3.541240427781124*^9, 3.541240438922859*^9}, {
   3.541240685803563*^9, 3.5412406968684883`*^9}, {3.541240745854438*^9, 
   3.541240766248905*^9}, {3.541240828973681*^9, 3.541240833751522*^9}, {
   3.5438458434437943`*^9, 3.543845859150589*^9}, 3.545225929472177*^9, 
   3.546002415899541*^9, 3.547111154129519*^9, 3.570223038548759*^9, 
   3.570223091862494*^9, 3.570232886702614*^9, 3.5702337275010633`*^9, 
   3.5702340814800777`*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"-", 
   FractionBox[
    RowBox[{"6", " ", "\[ImaginaryI]", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "l"}], ")"}], " ", "l", " ", 
     RowBox[{"(", 
      RowBox[{"1", "+", "l"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"2", "+", "l"}], ")"}], " ", "M", " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", "\[Alpha]", 
     " ", 
     RowBox[{"G1", "[", "r", "]"}]}], 
    RowBox[{
     SuperscriptBox["r", "6"], " ", "\[Beta]", " ", "\[Omega]"}]]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "-", 
          FractionBox[
           RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"2", " ", "M"}], "+", 
          RowBox[{"l", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", "l"}], ")"}], " ", "r", " ", 
           RowBox[{"(", 
            RowBox[{"1", "+", 
             FractionBox[
              RowBox[{"576", " ", 
               SuperscriptBox["M", "2"], " ", "\[Pi]", " ", 
               SuperscriptBox["\[Alpha]", "2"]}], 
              RowBox[{
               SuperscriptBox["r", "6"], " ", "\[Beta]"}]]}], ")"}]}]}], 
         ")"}]}], 
       SuperscriptBox["r", "3"]]}], "+", 
     SuperscriptBox["\[Omega]", "2"]}], ")"}], " ", 
   RowBox[{"G2", "[", "r", "]"}]}], "+", 
  FractionBox[
   RowBox[{"2", " ", "M", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"n", "+", 
         RowBox[{"kk", " ", "r"}]}], ")"}], " ", 
       RowBox[{"G2", "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{
        SuperscriptBox["G2", "\[Prime]",
         MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
   SuperscriptBox["r", "4"]], "+", 
  FractionBox[
   RowBox[{
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "1"}], "+", "n"}], ")"}], " ", "n"}], "+", 
         RowBox[{"2", " ", "kk", " ", "n", " ", "r"}], "+", 
         RowBox[{
          SuperscriptBox["kk", "2"], " ", 
          SuperscriptBox["r", "2"]}]}], ")"}], " ", 
       RowBox[{"G2", "[", "r", "]"}]}], "+", 
      RowBox[{"r", " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{"n", "+", 
            RowBox[{"kk", " ", "r"}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["G2", "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], "+", 
         RowBox[{"r", " ", 
          RowBox[{
           SuperscriptBox["G2", "\[Prime]\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], ")"}]}], 
   SuperscriptBox["r", "4"]]}]], "Output",
 CellChangeTimes->{{3.541240427781124*^9, 3.541240438922859*^9}, {
   3.541240685803563*^9, 3.5412406968684883`*^9}, {3.541240745854438*^9, 
   3.541240766248905*^9}, {3.541240828973681*^9, 3.541240833751522*^9}, {
   3.5438458434437943`*^9, 3.543845859150589*^9}, 3.545225929472177*^9, 
   3.546002415899541*^9, 3.547111154129519*^9, 3.570223038548759*^9, 
   3.570223091862494*^9, 3.570232886702614*^9, 3.5702337275010633`*^9, 
   3.57023408336014*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"ORDinf", "=", "2"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"G1", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"u1inf", "[", "i", "]"}], 
      SuperscriptBox["r", "i"]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"ORDinf", "+", "3"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"G2", "[", "r_", "]"}], ":=", 
   RowBox[{"Sum", "[", 
    RowBox[{
     FractionBox[
      RowBox[{"u2inf", "[", "i", "]"}], 
      SuperscriptBox["r", "i"]], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", 
       RowBox[{"ORDinf", "+", "3"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleINF", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["kk", "2"], "\[Rule]", 
      RowBox[{"-", 
       SuperscriptBox["\[Omega]", "2"]}]}], ",", 
     RowBox[{"n", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "M", " ", 
         SuperscriptBox["\[Omega]", "2"]}], "kk"]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ss", "=", 
   RowBox[{
    RowBox[{"Series", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"Es1", ",", "Es2"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"r", ",", "\[Infinity]", ",", 
        RowBox[{"ORDinf", "+", "3"}]}], "}"}]}], "]"}], "/.", "ruleINF"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"yinf", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"u1inf", "[", "i", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"ORDinf", "+", "1"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"u2inf", "[", "i", "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"ORDinf", "+", "1"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQsinf", "=", 
   RowBox[{"Union", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{
          RowBox[{"ss", "[", 
           RowBox[{"[", "1", "]"}], "]"}], ",", "i"}], "]"}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", 
         RowBox[{"ORDinf", "+", "2"}]}], "}"}]}], "]"}], ",", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"SeriesCoefficient", "[", 
         RowBox[{
          RowBox[{"ss", "[", 
           RowBox[{"[", "2", "]"}], "]"}], ",", "i"}], "]"}], "\[Equal]", 
        "0"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "2", ",", 
         RowBox[{"ORDinf", "+", "2"}]}], "}"}]}], "]"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "yinf", "]"}], "\[IndentingNewLine]", 
 RowBox[{"Length", "[", "EQsinf", "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"seriesINF", "=", 
   RowBox[{
    RowBox[{
     RowBox[{"Solve", "[", 
      RowBox[{"EQsinf", ",", "yinf"}], "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}], "//", "Simplify"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"Clear", "[", 
  RowBox[{"u1", ",", "u2", ",", "G1", ",", "G2"}], "]"}]}], "Input",
 CellChangeTimes->{{3.541240468031693*^9, 3.5412405944647093`*^9}, {
   3.541240715797538*^9, 3.541240750258874*^9}, 3.541240781864942*^9, {
   3.54124083853787*^9, 3.5412408705784607`*^9}, {3.54124093445772*^9, 
   3.541240989521738*^9}, {3.541241038480195*^9, 3.541241049581852*^9}, {
   3.541241129083001*^9, 3.54124113354723*^9}, 3.54124127315641*^9, 
   3.541241304747508*^9, {3.5702230554676857`*^9, 3.570223217990988*^9}}],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{
  3.5412405954204683`*^9, {3.5412407075681953`*^9, 3.541240716462205*^9}, {
   3.541240752170784*^9, 3.541240782840434*^9}, 3.5412408401736298`*^9, 
   3.541240944890541*^9, 3.541240991159762*^9, {3.541241039156106*^9, 
   3.54124105173921*^9}, 3.541241135429797*^9, {3.54124127789135*^9, 
   3.5412413057949677`*^9}, 3.543845862991049*^9, 3.545225931914119*^9, 
   3.5460024244310417`*^9, 3.547111157106203*^9, {3.570223060126832*^9, 
   3.5702230741507673`*^9}, {3.570223109288637*^9, 3.570223119378471*^9}, {
   3.5702231536052923`*^9, 3.570223218453847*^9}, 3.570232888977373*^9, 
   3.570233729593122*^9, 3.5702340836088877`*^9}],

Cell[BoxData["6"], "Output",
 CellChangeTimes->{
  3.5412405954204683`*^9, {3.5412407075681953`*^9, 3.541240716462205*^9}, {
   3.541240752170784*^9, 3.541240782840434*^9}, 3.5412408401736298`*^9, 
   3.541240944890541*^9, 3.541240991159762*^9, {3.541241039156106*^9, 
   3.54124105173921*^9}, 3.541241135429797*^9, {3.54124127789135*^9, 
   3.5412413057949677`*^9}, 3.543845862991049*^9, 3.545225931914119*^9, 
   3.5460024244310417`*^9, 3.547111157106203*^9, {3.570223060126832*^9, 
   3.5702230741507673`*^9}, {3.570223109288637*^9, 3.570223119378471*^9}, {
   3.5702231536052923`*^9, 3.570223218453847*^9}, 3.570232888977373*^9, 
   3.570233729593122*^9, 3.570234083609432*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"DumpSave", "[", 
    RowBox[{"\"\<seriesINF.mx\>\"", ",", 
     RowBox[{"{", 
      RowBox[{"seriesINF", ",", "ORDinf"}], "}"}]}], "]"}], ";"}], 
  "*)"}]], "Input",
 CellChangeTimes->{{3.5412412231657963`*^9, 3.541241223660211*^9}, {
  3.570223234851224*^9, 3.570223237777561*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Higher order BCs at infinity", "Subsubsection",
 CellChangeTimes->{{3.5412432060079536`*^9, 3.541243209063484*^9}, {
  3.5702274721975813`*^9, 3.5702274808868513`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"<<", "\"\<seriesINF.mx\>\""}], ";"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ORDinf2", "=", 
     RowBox[{"(", 
      RowBox[{"ORDinf", "+", "1"}], ")"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"ORDinf2", "=", "0"}], ";"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"y1", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"u1inf", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "ORDinf2"}], "}"}]}], "]"}], "//.", 
         RowBox[{"Union", "[", 
          RowBox[{"seriesINF", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"u1inf", "[", "0", "]"}], "\[Rule]", "B1"}], ",", 
             RowBox[{
              RowBox[{"u2inf", "[", "0", "]"}], "\[Rule]", "B2"}], ",", 
             RowBox[{"kk", "\[Rule]", 
              RowBox[{"-", "k"}]}]}], "}"}]}], "]"}]}], ")"}], " ", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "k"}], " ", "r"}], "]"}], 
       SuperscriptBox["r", 
        FractionBox[
         RowBox[{"2", " ", "M", " ", 
          SuperscriptBox["\[Omega]", "2"]}], "k"]]}], "+", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"u1inf", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "ORDinf2"}], "}"}]}], "]"}], "//.", 
         RowBox[{"Union", "[", 
          RowBox[{"seriesINF", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"u1inf", "[", "0", "]"}], "\[Rule]", "C1"}], ",", 
             RowBox[{
              RowBox[{"u2inf", "[", "0", "]"}], "\[Rule]", "C2"}], ",", 
             RowBox[{"kk", "\[Rule]", "k"}]}], "}"}]}], "]"}]}], ")"}], " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"k", " ", "r"}], "]"}], 
       SuperscriptBox["r", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "M", " ", 
           SuperscriptBox["\[Omega]", "2"]}], "k"]}]]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"y1p", "=", 
     RowBox[{"D", "[", 
      RowBox[{"y1", ",", "r"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"y2", "=", " ", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"u2inf", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "ORDinf2"}], "}"}]}], "]"}], "//.", 
         RowBox[{"Union", "[", 
          RowBox[{"seriesINF", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"u1inf", "[", "0", "]"}], "\[Rule]", "B1"}], ",", 
             RowBox[{
              RowBox[{"u2inf", "[", "0", "]"}], "\[Rule]", "B2"}], ",", 
             RowBox[{"kk", "\[Rule]", 
              RowBox[{"-", "k"}]}]}], "}"}]}], "]"}]}], ")"}], " ", 
       RowBox[{"Exp", "[", 
        RowBox[{
         RowBox[{"-", "k"}], " ", "r"}], "]"}], 
       SuperscriptBox["r", 
        FractionBox[
         RowBox[{"2", " ", "M", " ", 
          SuperscriptBox["\[Omega]", "2"]}], "k"]]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Sum", "[", 
          RowBox[{
           FractionBox[
            RowBox[{"u2inf", "[", "i", "]"}], 
            SuperscriptBox["r", "i"]], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "0", ",", "ORDinf2"}], "}"}]}], "]"}], "//.", 
         RowBox[{"Union", "[", 
          RowBox[{"seriesINF", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{
              RowBox[{"u1inf", "[", "0", "]"}], "\[Rule]", "C1"}], ",", 
             RowBox[{
              RowBox[{"u2inf", "[", "0", "]"}], "\[Rule]", "C2"}], ",", 
             RowBox[{"kk", "\[Rule]", "k"}]}], "}"}]}], "]"}]}], ")"}], " ", 
       RowBox[{"Exp", "[", 
        RowBox[{"k", " ", "r"}], "]"}], 
       SuperscriptBox["r", 
        RowBox[{"-", 
         FractionBox[
          RowBox[{"2", " ", "M", " ", 
           SuperscriptBox["\[Omega]", "2"]}], "k"]}]]}]}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"y2p", "=", 
     RowBox[{"D", "[", 
      RowBox[{"y2", ",", "r"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solBC", "=", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"y1", "\[Equal]", "Y1"}], ",", 
         RowBox[{"y1p", "\[Equal]", "Y1p"}], ",", 
         RowBox[{"y2", "\[Equal]", "Y2"}], ",", 
         RowBox[{"y2p", "\[Equal]", "Y2p"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"B1", ",", "C1", ",", "B2", ",", "C2"}], "}"}]}], "]"}]}], 
    ";"}], "\[IndentingNewLine]", 
   RowBox[{"Length", "[", "solBC", "]"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"solBC", "=", 
     RowBox[{"solBC", "[", 
      RowBox[{"[", "1", "]"}], "]"}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.5412414498895063`*^9, 3.541241451825223*^9}, {
   3.541241820429599*^9, 3.541241877067543*^9}, {3.541241914038664*^9, 
   3.5412419185605583`*^9}, {3.5412420194719677`*^9, 
   3.5412420628150597`*^9}, {3.541242243794663*^9, 3.541242325378422*^9}, {
   3.541242377291679*^9, 3.541242449716723*^9}, {3.54124289469874*^9, 
   3.541242917942212*^9}, {3.541242972970052*^9, 3.5412430124490128`*^9}, {
   3.541243183711152*^9, 3.541243198651471*^9}, {3.541243243544005*^9, 
   3.541243295494513*^9}, {3.5412433310756807`*^9, 3.541243384269206*^9}, 
   3.541243602770397*^9, 3.541243894341625*^9, {3.54124405714715*^9, 
   3.541244067574277*^9}, {3.543063740277933*^9, 3.543063744699192*^9}, 
   3.543064786809597*^9, 3.5460024513058*^9, {3.546002614156507*^9, 
   3.546002652347048*^9}, 3.546002732298641*^9, {3.546155762894256*^9, 
   3.546155763523748*^9}, 3.547111195533031*^9, {3.547111390900504*^9, 
   3.547111392696575*^9}, {3.547111543614118*^9, 3.547111545170849*^9}, 
   3.547111642536331*^9, {3.570223566371401*^9, 3.570223644127458*^9}, {
   3.570223689504027*^9, 3.570223721871916*^9}, {3.5702242573394623`*^9, 
   3.570224262124525*^9}}],

Cell[BoxData["1"], "Output",
 CellChangeTimes->{
  3.543063563293985*^9, 3.543063747959791*^9, {3.543064791474237*^9, 
   3.54306480375646*^9}, 3.543845881836447*^9, 3.545225953680488*^9, 
   3.546002440943503*^9, 3.546002546427096*^9, 3.54600261546488*^9, {
   3.546002653114089*^9, 3.546002657387272*^9}, 3.546002735622032*^9, 
   3.5461538004738197`*^9, 3.546155763985011*^9, 3.54615583973798*^9, 
   3.546247727631073*^9, 3.546260682161497*^9, 3.547111395599411*^9, {
   3.547111541499783*^9, 3.547111548527124*^9}, 3.547111642965418*^9, 
   3.5702237254196177`*^9, 3.570224200135*^9, 3.570224266582231*^9, 
   3.5702328901792183`*^9, 3.570233730741238*^9, 3.570234084754237*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"(*", 
  RowBox[{
   RowBox[{"SetDirectory", "[", 
    RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";", 
   "\[IndentingNewLine]", 
   RowBox[{"DumpSave", "[", 
    RowBox[{"\"\<solBC.mx\>\"", ",", 
     RowBox[{"{", "solBC", "}"}]}], "]"}], ";"}], "*)"}]], "Input",
 CellChangeTimes->{{3.541244182733946*^9, 3.541244185860972*^9}, {
  3.570223733675527*^9, 3.570223736085059*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "solBC", "]"}]], "Input",
 CellChangeTimes->{{3.541243339790312*^9, 3.541243347489119*^9}}],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.5412433477789803`*^9, 3.543845882736496*^9, 
  3.5702237372773027`*^9, 3.570232890265745*^9, 3.570233730813266*^9, 
  3.570234084853462*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Integrator:", "Subsection",
 CellChangeTimes->{{3.540644807059821*^9, 3.540644809071306*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"INT", "[", 
    RowBox[{
    "\[Omega]0_", ",", "\[Alpha]0_", ",", "u10_", ",", "u20_", ",", "l0_", 
     ",", "EPS_", ",", "INF_"}], "]"}], ":=", 
   RowBox[{"(", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"ruleP", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"AccuracyGoal", "\[Rule]", "80"}], ",", 
        RowBox[{"PrecisionGoal", "\[Rule]", "12"}], ",", 
        RowBox[{"MaxSteps", "\[Rule]", 
         SuperscriptBox["10", "5"]}]}], "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"ruleP", "=", 
      RowBox[{"{", "}"}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
     RowBox[{"param", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"M", "\[Rule]", "1"}], ",", 
        RowBox[{"l", "\[Rule]", "l0"}], ",", 
        RowBox[{"\[Omega]", "\[Rule]", "\[Omega]0"}], ",", 
        RowBox[{
         RowBox[{"u1h", "[", "0", "]"}], "\[Rule]", "u10"}], ",", 
        RowBox[{
         RowBox[{"u2h", "[", "0", "]"}], "\[Rule]", "u20"}], ",", 
        RowBox[{"\[Beta]", "\[Rule]", "1"}], ",", 
        RowBox[{"\[Alpha]", "\[Rule]", "\[Alpha]0"}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rhn", "=", 
      RowBox[{
       RowBox[{"2", "M", 
        RowBox[{"(", 
         RowBox[{"1", "+", "EPS"}], ")"}]}], "/.", "param"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"rinf", "=", "INF"}], ";", "\[IndentingNewLine]", 
     "\[IndentingNewLine]", 
     RowBox[{"(*", 
      RowBox[{
       RowBox[{"<<", "\"\<seriesH.mx\>\""}], ";"}], "*)"}], 
     "\[IndentingNewLine]", 
     RowBox[{"u1g", "=", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", "M"}]}], ")"}], 
         RowBox[{
          RowBox[{"-", "2"}], "I", " ", "\[Omega]", " ", "M"}]], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"u1h", "[", "i", "]"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", "M"}]}], ")"}], "i"]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "ORD"}], "}"}]}], "]"}]}], "//.", 
       RowBox[{"Union", "[", 
        RowBox[{"param", ",", "seriesH"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"u2g", "=", 
      RowBox[{
       RowBox[{
        SuperscriptBox[
         RowBox[{"(", 
          RowBox[{"r", "-", 
           RowBox[{"2", "M"}]}], ")"}], 
         RowBox[{
          RowBox[{"-", "2"}], "I", " ", "\[Omega]", " ", "M"}]], 
        RowBox[{"Sum", "[", 
         RowBox[{
          RowBox[{
           RowBox[{"u2h", "[", "i", "]"}], 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{"r", "-", 
              RowBox[{"2", "M"}]}], ")"}], "i"]}], ",", 
          RowBox[{"{", 
           RowBox[{"i", ",", "0", ",", "ORD"}], "}"}]}], "]"}]}], "//.", 
       RowBox[{"Union", "[", 
        RowBox[{"param", ",", "seriesH"}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"EQs", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"-", 
                   FractionBox[
                    RowBox[{"6", " ", "M"}], 
                    SuperscriptBox["r", "3"]]}], "+", 
                  FractionBox[
                   RowBox[{"l", " ", 
                    RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}]}], 
                   SuperscriptBox["r", "2"]]}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{"1", "-", 
                 FractionBox[
                  RowBox[{"2", " ", "M"}], "r"]}], ")"}]}], "+", 
              SuperscriptBox["\[Omega]", "2"]}], ")"}], " ", 
            RowBox[{"u1", "[", "r", "]"}]}], "-", 
           FractionBox[
            RowBox[{"96", " ", "\[ImaginaryI]", " ", "M", " ", "\[Pi]", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", "\[Alpha]", " ", 
             "\[Omega]", " ", 
             RowBox[{"u2", "[", "r", "]"}]}], 
            SuperscriptBox["r", "5"]], "+", 
           FractionBox[
            RowBox[{"2", " ", "M", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["u1", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], 
            SuperscriptBox["r", "2"]], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                RowBox[{"2", " ", "M"}], "r"]}], ")"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["u1", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], "\[Equal]", 
          "0"}], ",", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            FractionBox[
             RowBox[{"6", " ", "\[ImaginaryI]", " ", "M", " ", 
              RowBox[{"(", 
               RowBox[{"1", "-", 
                FractionBox[
                 RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", "\[Alpha]", " ", 
              RowBox[{
               RowBox[{"(", 
                RowBox[{"2", "+", "l"}], ")"}], "!"}], " ", 
              RowBox[{"u1", "[", "r", "]"}]}], 
             RowBox[{
              SuperscriptBox["r", "5"], " ", "\[Beta]", " ", "\[Omega]", " ", 
              
              RowBox[{
               RowBox[{"(", 
                RowBox[{
                 RowBox[{"-", "2"}], "+", "l"}], ")"}], "!"}]}]]}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", 
                RowBox[{"(", 
                 RowBox[{"1", "-", 
                  FractionBox[
                   RowBox[{"2", " ", "M"}], "r"]}], ")"}]}], " ", 
               RowBox[{"(", 
                RowBox[{
                 FractionBox[
                  RowBox[{"2", " ", "M"}], 
                  SuperscriptBox["r", "3"]], "+", 
                 FractionBox[
                  RowBox[{"l", " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", "l"}], ")"}], " ", 
                   RowBox[{"(", 
                    RowBox[{"1", "+", 
                    FractionBox[
                    RowBox[{"576", " ", 
                    SuperscriptBox["M", "2"], " ", "\[Pi]", " ", 
                    SuperscriptBox["\[Alpha]", "2"]}], 
                    RowBox[{
                    SuperscriptBox["r", "6"], " ", "\[Beta]"}]]}], ")"}]}], 
                  SuperscriptBox["r", "2"]]}], ")"}]}], "+", 
              SuperscriptBox["\[Omega]", "2"]}], ")"}], " ", 
            RowBox[{"u2", "[", "r", "]"}]}], "+", 
           FractionBox[
            RowBox[{"2", " ", "M", " ", 
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                RowBox[{"2", " ", "M"}], "r"]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["u2", "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], 
            SuperscriptBox["r", "2"]], "+", 
           RowBox[{
            SuperscriptBox[
             RowBox[{"(", 
              RowBox[{"1", "-", 
               FractionBox[
                RowBox[{"2", " ", "M"}], "r"]}], ")"}], "2"], " ", 
            RowBox[{
             SuperscriptBox["u2", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], "\[Equal]", 
          "0"}]}], "}"}], "//.", "param"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"BCs", "=", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"u1", "[", "rhn", "]"}], "\[Equal]", "u1g"}], "/.", 
         RowBox[{"r", "\[Rule]", "rhn"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"u1", "'"}], "[", "rhn", "]"}], "\[Equal]", 
          RowBox[{"D", "[", 
           RowBox[{"u1g", ",", "r"}], "]"}]}], "/.", 
         RowBox[{"r", "\[Rule]", "rhn"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"u2", "[", "rhn", "]"}], "\[Equal]", "u2g"}], "/.", 
         RowBox[{"r", "\[Rule]", "rhn"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{
           RowBox[{"u2", "'"}], "[", "rhn", "]"}], "\[Equal]", 
          RowBox[{"D", "[", 
           RowBox[{"u2g", ",", "r"}], "]"}]}], "/.", 
         RowBox[{"r", "\[Rule]", "rhn"}]}]}], "}"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"sol", "=", 
      RowBox[{"NDSolve", "[", 
       RowBox[{
        RowBox[{"Union", "[", 
         RowBox[{"EQs", ",", "BCs"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"u1", ",", "u2"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"r", ",", "rhn", ",", "rinf"}], "}"}], ",", "ruleP"}], 
       "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"u1n", "=", 
      RowBox[{
       RowBox[{"u1", "[", "r", "]"}], "/.", 
       RowBox[{"sol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"u2n", "=", 
      RowBox[{
       RowBox[{"u2", "[", "r", "]"}], "/.", 
       RowBox[{"sol", "[", 
        RowBox[{"[", "1", "]"}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
    "\[IndentingNewLine]", ")"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5406389567025223`*^9, 3.540639172716782*^9}, {
   3.540639232434269*^9, 3.5406393330383043`*^9}, {3.5406393697939653`*^9, 
   3.540639441625225*^9}, {3.540639613518202*^9, 3.540639640285192*^9}, {
   3.540643004823125*^9, 3.540643013980109*^9}, {3.5406449682608833`*^9, 
   3.5406449695598803`*^9}, {3.54064503561178*^9, 3.540645035893281*^9}, {
   3.540648377512472*^9, 3.540648379814666*^9}, {3.540706996822343*^9, 
   3.540707023970501*^9}, {3.5407194504130383`*^9, 3.5407194508095713`*^9}, {
   3.541161882974161*^9, 3.541161899001609*^9}, 3.5412271807876062`*^9, 
   3.54123157528649*^9, 3.5430648002648373`*^9, {3.570223358669942*^9, 
   3.5702233849351788`*^9}, {3.570223460104187*^9, 3.5702235583826103`*^9}, {
   3.570224104250095*^9, 3.570224117512864*^9}, {3.570232887357041*^9, 
   3.570232887900847*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"INT", "[", 
   RowBox[{
    RowBox[{"0.1", "-", 
     RowBox[{"0.1", "I"}]}], ",", "1", ",", "1", ",", "1", ",", "2", ",", 
    SuperscriptBox["10", 
     RowBox[{"-", "4"}]], ",", 
    SuperscriptBox["10", "2"]}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"{", 
   RowBox[{"u1n", ",", "u2n"}], "}"}], "/.", 
  RowBox[{"r", "\[Rule]", "rinf"}]}]}], "Input",
 CellChangeTimes->{{3.570223898116459*^9, 3.57022390943139*^9}, 
   3.5702240255094147`*^9, {3.5702241397925243`*^9, 3.570224195116805*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"6.257173961070277`*^10", "-", 
    RowBox[{"1.1474944603883546`*^11", " ", "\[ImaginaryI]"}]}], ",", 
   RowBox[{
    RowBox[{"-", "3.3537375491056335`*^11"}], "-", 
    RowBox[{"1.0763823946449742`*^12", " ", "\[ImaginaryI]"}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{{3.5702241895166817`*^9, 3.570224195534739*^9}, 
   3.570232891264935*^9, 3.570233730981092*^9, 3.5702340856064053`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["DETERMINANT", "Subsubsection",
 CellChangeTimes->{{3.541511985719203*^9, 3.54151198912698*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LINCOMB", "[", 
   RowBox[{
   "\[Omega]0_", ",", "\[Alpha]0_", ",", "l0_", ",", "EPS_", ",", "INF_"}], 
   "]"}], ":=", 
  RowBox[{"(", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"<<", "\"\<polar_solBC.mx\>\""}], ";"}], "*)"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"INT", "[", 
     RowBox[{
     "\[Omega]0", ",", "\[Alpha]0", ",", "1", ",", "0", ",", "l0", ",", "EPS",
       ",", "INF"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"u110", "=", "u1n"}], ";", "\[IndentingNewLine]", 
    RowBox[{"u210", "=", "u2n"}], ";", "\[IndentingNewLine]", 
    RowBox[{"u110p", "=", 
     RowBox[{"D", "[", 
      RowBox[{"u1n", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"u210p", "=", 
     RowBox[{"D", "[", 
      RowBox[{"u2n", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"rule10", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"solBC", ",", "param", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"k", "\[Rule]", 
          RowBox[{"I", " ", "\[Omega]"}]}], ",", 
         RowBox[{"Y1", "\[Rule]", "u110"}], ",", 
         RowBox[{"Y1p", "\[Rule]", "u110p"}], ",", 
         RowBox[{"Y2", "\[Rule]", "u210"}], ",", 
         RowBox[{"Y2p", "\[Rule]", "u210p"}], ",", 
         RowBox[{"r", "\[Rule]", "rinf"}]}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"B110", "=", 
     RowBox[{"B1", "//.", "rule10"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"C110", "=", 
     RowBox[{"C1", "//.", "rule10"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"B210", "=", 
     RowBox[{"B2", "//.", "rule10"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"C210", "=", 
     RowBox[{"C2", "//.", "rule10"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"INT", "[", 
     RowBox[{
     "\[Omega]0", ",", "\[Alpha]0", ",", "0", ",", "1", ",", "l0", ",", "EPS",
       ",", "INF"}], "]"}], ";", "\[IndentingNewLine]", 
    RowBox[{"u101", "=", "u1n"}], ";", "\[IndentingNewLine]", 
    RowBox[{"u201", "=", "u2n"}], ";", "\[IndentingNewLine]", 
    RowBox[{"u101p", "=", 
     RowBox[{"D", "[", 
      RowBox[{"u1n", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"u201p", "=", 
     RowBox[{"D", "[", 
      RowBox[{"u2n", ",", "r"}], "]"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"rule01", "=", 
     RowBox[{"Union", "[", 
      RowBox[{"solBC", ",", "param", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"k", "\[Rule]", 
          RowBox[{"I", " ", "\[Omega]"}]}], ",", 
         RowBox[{"Y1", "\[Rule]", "u101"}], ",", 
         RowBox[{"Y1p", "\[Rule]", "u101p"}], ",", 
         RowBox[{"Y2", "\[Rule]", "u201"}], ",", 
         RowBox[{"Y2p", "\[Rule]", "u201p"}], ",", 
         RowBox[{"r", "\[Rule]", "rinf"}]}], "}"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"B101", "=", 
     RowBox[{"B1", "//.", "rule01"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"C101", "=", 
     RowBox[{"C1", "//.", "rule01"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"B201", "=", 
     RowBox[{"B2", "//.", "rule01"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"C201", "=", 
     RowBox[{"C2", "//.", "rule01"}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"(*", 
     RowBox[{"**", "**", "**"}], "*****)"}], "\[IndentingNewLine]", 
    RowBox[{"BB", "=", 
     RowBox[{
      RowBox[{"B110", " ", "B201"}], "-", 
      RowBox[{"B101", " ", "B210"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"CC", "=", 
     RowBox[{
      RowBox[{"C110", " ", "C201"}], "-", 
      RowBox[{"C101", " ", "C210"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"{", "BB", "}"}]}], 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"BB", " ", "for", " ", "QNMs"}], ",", " ", 
     RowBox[{
      RowBox[{"CC", " ", "for", " ", "quasi"}], "-", 
      RowBox[{"bound", " ", "states"}]}]}], "*)"}], "\[IndentingNewLine]", 
   ")"}]}]}], "Input",
 CellChangeTimes->{{3.540639650959386*^9, 3.5406396580220613`*^9}, {
   3.5406401715329313`*^9, 3.540640332771872*^9}, {3.540640538764817*^9, 
   3.540640543507307*^9}, {3.540640604924336*^9, 3.5406406445323877`*^9}, {
   3.5406408523754377`*^9, 3.54064094389855*^9}, {3.540644824080893*^9, 
   3.540644836297217*^9}, {3.540646088137024*^9, 3.54064609182734*^9}, {
   3.5406462883982353`*^9, 3.5406462885764103`*^9}, {3.540646432842512*^9, 
   3.540646436672494*^9}, {3.540647292410907*^9, 3.540647296652605*^9}, {
   3.540704224302143*^9, 3.540704290941416*^9}, {3.540704555900629*^9, 
   3.540704575074337*^9}, {3.540704616305812*^9, 3.540704616472355*^9}, {
   3.541225318050675*^9, 3.541225322733266*^9}, {3.541226096561871*^9, 
   3.5412261248374157`*^9}, {3.541226159788381*^9, 3.5412263526195097`*^9}, {
   3.5412263828544416`*^9, 3.541226406225265*^9}, {3.541243022312667*^9, 
   3.541243160163334*^9}, {3.541244191938911*^9, 3.541244209476408*^9}, 
   3.5418498996025057`*^9, {3.545225988246513*^9, 3.54522599842393*^9}, {
   3.5702237501220293`*^9, 3.570223879379117*^9}, {3.570224204430812*^9, 
   3.570224268752021*^9}, {3.5702244550328608`*^9, 3.5702244769344387`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LINCOMB", "[", 
  RowBox[{
   RowBox[{"0.1", "+", 
    RowBox[{"0.0001", "I"}]}], ",", "1", ",", "2", ",", 
   SuperscriptBox["10", 
    RowBox[{"-", "6"}]], ",", 
   SuperscriptBox["10", "2"]}], "]"}]], "Input",
 CellChangeTimes->{{3.5406403148836184`*^9, 3.540640338292017*^9}, {
  3.540643749337723*^9, 3.540643767272091*^9}, {3.540704605069368*^9, 
  3.5407046102443037`*^9}, {3.570223883284616*^9, 3.57022388550426*^9}, {
  3.570224220760027*^9, 3.570224221121052*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"9.425250891123438`*^10", "-", 
   RowBox[{"5.5168791391984375`*^10", " ", "\[ImaginaryI]"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5406403391923113`*^9, 3.540640561398025*^9, 3.540640606287476*^9, {
   3.540640638631174*^9, 3.54064064606292*^9}, 3.5406408554268703`*^9, {
   3.54064092839883*^9, 3.540640945315172*^9}, 3.540641244244258*^9, 
   3.540641386513082*^9, {3.540643745033473*^9, 3.540643767707231*^9}, 
   3.540644842387645*^9, 3.5406449555034227`*^9, 3.540645060059313*^9, 
   3.540646291121771*^9, 3.540646439749041*^9, 3.5406466242707567`*^9, 
   3.540647308231732*^9, 3.540648384197268*^9, 3.540704534143898*^9, 
   3.5407045776604567`*^9, {3.5407046108392076`*^9, 3.540704619239834*^9}, 
   3.5407069042324133`*^9, 3.540706948662486*^9, 3.540707035531301*^9, 
   3.540719157832858*^9, 3.540719460918579*^9, 3.540719505520277*^9, 
   3.541160215244979*^9, 3.541160765510127*^9, 3.5411611009169807`*^9, {
   3.541226370924162*^9, 3.54122641177183*^9}, 3.5412333417074213`*^9, 
   3.5412344608487988`*^9, {3.5412431927417507`*^9, 3.541243216568618*^9}, 
   3.5412436176122417`*^9, 3.5412442314501677`*^9, 3.54126054803903*^9, 
   3.541512007359332*^9, 3.5430638810434303`*^9, 3.543845897404153*^9, 
   3.5452259624322987`*^9, 3.54600274241016*^9, 3.5461538081512203`*^9, 
   3.5461557714191628`*^9, 3.5461558449482517`*^9, 3.5462477287709208`*^9, 
   3.546260688392556*^9, 3.547111559335671*^9, 3.547111651437091*^9, 
   3.5702238866309967`*^9, {3.570224221762561*^9, 3.570224269965869*^9}, {
   3.570224457126224*^9, 3.57022447831975*^9}, 3.570232895234953*^9, 
   3.570233731341957*^9, 3.570234089414239*^9}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Find root:", "Subsubsection",
 CellChangeTimes->{{3.54624824169519*^9, 3.546248242544744*^9}, {
  3.570227529289559*^9, 3.570227532570793*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]guess", "=", 
    RowBox[{"0.48", "\[VeryThinSpace]", "-", 
     RowBox[{"0.1", " ", "\[ImaginaryI]"}]}]}], ";"}], 
  RowBox[{"(*", "grav", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]guess", "=", 
    RowBox[{"0.3", "\[VeryThinSpace]", "-", 
     RowBox[{"0.1", " ", "\[ImaginaryI]"}]}]}], ";"}], 
  RowBox[{"(*", "scal", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**"}], "*****)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f4", "[", 
    RowBox[{"y_", "?", "NumericQ"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"LINCOMB", "[", 
     RowBox[{"y", ",", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]], ",", "2", ",", 
      RowBox[{"1", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]]}], ",", "30"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"y0n", "=", 
  RowBox[{"y", "/.", 
   RowBox[{
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f4", "[", "y", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "\[Omega]guess"}], "}"}]}], 
     RowBox[{"(*", 
      RowBox[{",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "2"}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "12"}]}], "*)"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Abs", "[", 
  RowBox[{"f4", "[", "y0n", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.540640409040543*^9, 3.54064042545057*^9}, {
   3.5406404559532757`*^9, 3.540640487057073*^9}, {3.540640549901157*^9, 
   3.540640550826927*^9}, {3.540640670583375*^9, 3.540640730154347*^9}, {
   3.540640761378539*^9, 3.540640766635561*^9}, {3.54064080069508*^9, 
   3.540640811555477*^9}, {3.540640953538796*^9, 3.540641158503352*^9}, {
   3.540641406374235*^9, 3.540641420061475*^9}, {3.5406415621182947`*^9, 
   3.540641569919055*^9}, {3.540641631640499*^9, 3.540641637102079*^9}, {
   3.540641688928248*^9, 3.54064170139394*^9}, {3.540644521465933*^9, 
   3.540644530191144*^9}, {3.540645144377039*^9, 3.54064515837221*^9}, 
   3.540645224545512*^9, {3.540645255680593*^9, 3.540645401137281*^9}, 
   3.5406460961984158`*^9, 3.540646151322596*^9, {3.540647344014057*^9, 
   3.54064739507596*^9}, {3.540647434949544*^9, 3.5406474358391857`*^9}, {
   3.540704631477262*^9, 3.5407047906977777`*^9}, {3.540704821367272*^9, 
   3.540704821515333*^9}, {3.5407057899602337`*^9, 3.540705795885453*^9}, {
   3.540705833299431*^9, 3.540705979212254*^9}, 3.540708083680633*^9, {
   3.540708142606962*^9, 3.5407081713934813`*^9}, 3.5407082053016357`*^9, {
   3.540708246063858*^9, 3.54070825974714*^9}, 3.540710346717804*^9, {
   3.540719329126381*^9, 3.540719392017159*^9}, 3.540719471892127*^9, 
   3.5407195135287247`*^9, {3.5407199784120693`*^9, 3.540720054229109*^9}, {
   3.540720550501946*^9, 3.540720598311174*^9}, {3.540721070234262*^9, 
   3.540721264573799*^9}, {3.540721301377472*^9, 3.540721428537983*^9}, {
   3.5411602253891172`*^9, 3.541160245977396*^9}, {3.541163003433552*^9, 
   3.541163014330926*^9}, {3.541226442436843*^9, 3.541226493677372*^9}, {
   3.541226575793952*^9, 3.541226583845286*^9}, {3.541226632522155*^9, 
   3.5412266406794157`*^9}, 3.541226675956039*^9, {3.5412270952361603`*^9, 
   3.5412271592125177`*^9}, {3.54122722712033*^9, 3.541227238468721*^9}, {
   3.541227273309559*^9, 3.541227275078491*^9}, {3.541233170847823*^9, 
   3.541233251989602*^9}, {3.541233352279415*^9, 3.541233371904509*^9}, {
   3.541233409153061*^9, 3.541233547699046*^9}, 3.541243680562804*^9, {
   3.541243719831621*^9, 3.541243722104228*^9}, {3.541244240419671*^9, 
   3.5412442419414062`*^9}, 3.54126045575*^9, 3.541260493477393*^9, 
   3.5412605533217382`*^9, {3.5412606179128323`*^9, 3.541260621707213*^9}, 
   3.541260719629475*^9, 3.541307705331996*^9, 3.541307773177146*^9, 
   3.541308133840995*^9, {3.541308390703692*^9, 3.5413084006147223`*^9}, {
   3.5413087967647247`*^9, 3.541308797803729*^9}, {3.541512034055758*^9, 
   3.541512041696727*^9}, {3.5415122329120417`*^9, 3.541512236927578*^9}, {
   3.5415122867387657`*^9, 3.541512294215941*^9}, {3.541512385678061*^9, 
   3.541512389754486*^9}, 3.5415124710581636`*^9, {3.541512521573166*^9, 
   3.541512536683296*^9}, {3.541512648477215*^9, 3.5415126676066303`*^9}, 
   3.541512745423221*^9, {3.5415127994967537`*^9, 3.541512806998419*^9}, {
   3.541512897746273*^9, 3.5415128997707872`*^9}, {3.541512983229661*^9, 
   3.541512985398868*^9}, {3.541513044906458*^9, 3.5415130492002487`*^9}, {
   3.541513126566976*^9, 3.541513134147285*^9}, {3.541569762877513*^9, 
   3.541569771371152*^9}, {3.54157005922287*^9, 3.541570060332726*^9}, 
   3.5415702070915117`*^9, {3.541570451682013*^9, 3.541570455572055*^9}, {
   3.5415707042909803`*^9, 3.541570710173533*^9}, 3.541571038621105*^9, {
   3.541575845593234*^9, 3.541575858287315*^9}, {3.541575941090598*^9, 
   3.5415759424833517`*^9}, {3.5415760716092663`*^9, 
   3.5415760777720633`*^9}, {3.5415762051711063`*^9, 3.541576206139612*^9}, {
   3.541576360756578*^9, 3.5415763647092857`*^9}, {3.541576435542611*^9, 
   3.541576440550478*^9}, {3.541576709909539*^9, 3.541576713986745*^9}, {
   3.5415769303082857`*^9, 3.5415769347440243`*^9}, 3.541577114046023*^9, {
   3.543064103969022*^9, 3.543064137038541*^9}, {3.543064167122015*^9, 
   3.54306417793703*^9}, {3.543064252049169*^9, 3.5430642523044453`*^9}, {
   3.5430644625642023`*^9, 3.5430645108237743`*^9}, {3.5430645826113853`*^9, 
   3.5430645831730328`*^9}, {3.543064737883684*^9, 3.5430647382596693`*^9}, {
   3.543064841095715*^9, 3.543064874402994*^9}, {3.543064918620253*^9, 
   3.543064957614048*^9}, {3.543065399207594*^9, 3.543065447666004*^9}, 
   3.543069333186558*^9, {3.5438459175387077`*^9, 3.543845975635757*^9}, {
   3.545226027447884*^9, 3.5452260275789337`*^9}, {3.546002800953768*^9, 
   3.546002890265009*^9}, {3.546002923002837*^9, 3.546002924028316*^9}, {
   3.546153814172776*^9, 3.546153834565074*^9}, {3.5461538665403547`*^9, 
   3.546153978945874*^9}, {3.546155662285247*^9, 3.546155697882069*^9}, {
   3.546155785430122*^9, 3.546155810693411*^9}, {3.546155853398089*^9, 
   3.546155857196891*^9}, {3.546247734209504*^9, 3.546247734539815*^9}, {
   3.5471115640884743`*^9, 3.547111592767848*^9}, {3.547111667516321*^9, 
   3.54711166778428*^9}, {3.570224282115739*^9, 3.5702243220009413`*^9}, {
   3.570224383066101*^9, 3.570224393712757*^9}, {3.570224540537096*^9, 
   3.570224558905892*^9}, 3.570227534552004*^9}],

Cell[BoxData[
 RowBox[{"0.3730424640235457`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.08862037992260005`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.540641038294402*^9, 3.540641159047176*^9}, {
   3.5406413913051767`*^9, 3.5406414205621967`*^9}, 3.540641572370143*^9, 
   3.540641638959957*^9, 3.540644530834536*^9, {3.5406451472096453`*^9, 
   3.540645159146916*^9}, 3.540645225221682*^9, {3.5406452571184597`*^9, 
   3.540645329667535*^9}, {3.5406453672538843`*^9, 3.540645401610221*^9}, 
   3.540646096919957*^9, 3.540646152833391*^9, {3.540647372743726*^9, 
   3.540647398725678*^9}, {3.540704669808668*^9, 3.540704714520185*^9}, {
   3.540704775871418*^9, 3.540704791302834*^9}, 3.540704821914407*^9, 
   3.540705796653615*^9, 3.540705833686388*^9, {3.540705872654077*^9, 
   3.54070597965035*^9}, 3.540706951011766*^9, 3.540708090408354*^9, {
   3.540708152286853*^9, 3.5407081734427013`*^9}, 3.540708206185439*^9, {
   3.540708252518714*^9, 3.540708260623263*^9}, 3.540710347092958*^9, {
   3.5407193445296392`*^9, 3.540719384350062*^9}, 3.540719466171034*^9, {
   3.540719508506701*^9, 3.540719518356738*^9}, {3.540719987372149*^9, 
   3.540720054804085*^9}, {3.540720551521158*^9, 3.540720598984251*^9}, {
   3.540721075899622*^9, 3.540721265017913*^9}, {3.54072131924723*^9, 
   3.54072142365228*^9}, {3.5411602271140413`*^9, 3.541160246547501*^9}, 
   3.541160646493908*^9, 3.541161104337887*^9, 3.5411619087907343`*^9, {
   3.5411630043077497`*^9, 3.5411630152530518`*^9}, {3.541226425232889*^9, 
   3.5412264943197327`*^9}, {3.541226576373008*^9, 3.541226587141582*^9}, {
   3.541226633951749*^9, 3.5412266410664988`*^9}, 3.54122668004743*^9, {
   3.5412270971763363`*^9, 3.5412271599044123`*^9}, {3.541227232213773*^9, 
   3.541227238867959*^9}, 3.541227275963809*^9, 3.5412315829072237`*^9, {
   3.5412331754791927`*^9, 3.541233253664906*^9}, {3.541233347245007*^9, 
   3.541233372385597*^9}, {3.541233417317051*^9, 3.541233540124751*^9}, 
   3.541243640137169*^9, 3.541243681595481*^9, 3.541243723112852*^9, 
   3.54124424265422*^9, 3.5412604573886547`*^9, 3.5412604960465307`*^9, 
   3.541260553839506*^9, 3.541260622440199*^9, 3.5413076200194674`*^9, 
   3.541307708177421*^9, 3.541307774057857*^9, 3.541308135816407*^9, 
   3.541308401031447*^9, 3.541308798906425*^9, 3.541512046992133*^9, 
   3.5415122378700542`*^9, 3.54151229477452*^9, 3.541512390865068*^9, 
   3.541512476730919*^9, 3.5415125373524313`*^9, 3.541512664273636*^9, 
   3.541512747491485*^9, 3.541512807336828*^9, 3.5415129011262712`*^9, 
   3.541512986925935*^9, 3.541513053744988*^9, 3.541513135067745*^9, 
   3.541569772404182*^9, 3.5415700623209667`*^9, 3.541570297220149*^9, 
   3.5415704571393633`*^9, 3.541570711128563*^9, 3.541575859522731*^9, 
   3.541575945972968*^9, 3.541576078882113*^9, 3.541576208347329*^9, 
   3.541576366719902*^9, 3.5415764409578123`*^9, 3.541576717982485*^9, 
   3.541576935941092*^9, 3.543064254208578*^9, 3.5430645177082043`*^9, 
   3.543064739172735*^9, {3.54306484354856*^9, 3.543064875108886*^9}, {
   3.543064919883955*^9, 3.543064958463799*^9}, {3.5430654001716957`*^9, 
   3.543065448273386*^9}, 3.5430693336895657`*^9, {3.543845924677206*^9, 
   3.543845976103889*^9}, 3.54522596867283*^9, {3.545226005763097*^9, 
   3.5452260287815313`*^9}, 3.546002808789146*^9, {3.5460028501823263`*^9, 
   3.546002860122488*^9}, 3.546002891755363*^9, 3.546002925521739*^9, {
   3.5461538266630487`*^9, 3.546153835073926*^9}, {3.5461538670647163`*^9, 
   3.5461539795361853`*^9}, {3.546155664682662*^9, 3.546155698260282*^9}, {
   3.546155775902169*^9, 3.5461558112295303`*^9}, {3.5461558497491913`*^9, 
   3.546155857675139*^9}, {3.5471115732151337`*^9, 3.547111593614336*^9}, {
   3.547111654584794*^9, 3.547111668159227*^9}, 3.570224324884205*^9, 
   3.570224412646515*^9, {3.570224461250122*^9, 3.570224481284195*^9}, 
   3.570224549657918*^9, 3.570232901568438*^9, 3.5702337358048487`*^9, 
   3.57023409530602*^9}],

Cell[BoxData["2.061240350730387`*^-12"], "Output",
 CellChangeTimes->{{3.540641038294402*^9, 3.540641159047176*^9}, {
   3.5406413913051767`*^9, 3.5406414205621967`*^9}, 3.540641572370143*^9, 
   3.540641638959957*^9, 3.540644530834536*^9, {3.5406451472096453`*^9, 
   3.540645159146916*^9}, 3.540645225221682*^9, {3.5406452571184597`*^9, 
   3.540645329667535*^9}, {3.5406453672538843`*^9, 3.540645401610221*^9}, 
   3.540646096919957*^9, 3.540646152833391*^9, {3.540647372743726*^9, 
   3.540647398725678*^9}, {3.540704669808668*^9, 3.540704714520185*^9}, {
   3.540704775871418*^9, 3.540704791302834*^9}, 3.540704821914407*^9, 
   3.540705796653615*^9, 3.540705833686388*^9, {3.540705872654077*^9, 
   3.54070597965035*^9}, 3.540706951011766*^9, 3.540708090408354*^9, {
   3.540708152286853*^9, 3.5407081734427013`*^9}, 3.540708206185439*^9, {
   3.540708252518714*^9, 3.540708260623263*^9}, 3.540710347092958*^9, {
   3.5407193445296392`*^9, 3.540719384350062*^9}, 3.540719466171034*^9, {
   3.540719508506701*^9, 3.540719518356738*^9}, {3.540719987372149*^9, 
   3.540720054804085*^9}, {3.540720551521158*^9, 3.540720598984251*^9}, {
   3.540721075899622*^9, 3.540721265017913*^9}, {3.54072131924723*^9, 
   3.54072142365228*^9}, {3.5411602271140413`*^9, 3.541160246547501*^9}, 
   3.541160646493908*^9, 3.541161104337887*^9, 3.5411619087907343`*^9, {
   3.5411630043077497`*^9, 3.5411630152530518`*^9}, {3.541226425232889*^9, 
   3.5412264943197327`*^9}, {3.541226576373008*^9, 3.541226587141582*^9}, {
   3.541226633951749*^9, 3.5412266410664988`*^9}, 3.54122668004743*^9, {
   3.5412270971763363`*^9, 3.5412271599044123`*^9}, {3.541227232213773*^9, 
   3.541227238867959*^9}, 3.541227275963809*^9, 3.5412315829072237`*^9, {
   3.5412331754791927`*^9, 3.541233253664906*^9}, {3.541233347245007*^9, 
   3.541233372385597*^9}, {3.541233417317051*^9, 3.541233540124751*^9}, 
   3.541243640137169*^9, 3.541243681595481*^9, 3.541243723112852*^9, 
   3.54124424265422*^9, 3.5412604573886547`*^9, 3.5412604960465307`*^9, 
   3.541260553839506*^9, 3.541260622440199*^9, 3.5413076200194674`*^9, 
   3.541307708177421*^9, 3.541307774057857*^9, 3.541308135816407*^9, 
   3.541308401031447*^9, 3.541308798906425*^9, 3.541512046992133*^9, 
   3.5415122378700542`*^9, 3.54151229477452*^9, 3.541512390865068*^9, 
   3.541512476730919*^9, 3.5415125373524313`*^9, 3.541512664273636*^9, 
   3.541512747491485*^9, 3.541512807336828*^9, 3.5415129011262712`*^9, 
   3.541512986925935*^9, 3.541513053744988*^9, 3.541513135067745*^9, 
   3.541569772404182*^9, 3.5415700623209667`*^9, 3.541570297220149*^9, 
   3.5415704571393633`*^9, 3.541570711128563*^9, 3.541575859522731*^9, 
   3.541575945972968*^9, 3.541576078882113*^9, 3.541576208347329*^9, 
   3.541576366719902*^9, 3.5415764409578123`*^9, 3.541576717982485*^9, 
   3.541576935941092*^9, 3.543064254208578*^9, 3.5430645177082043`*^9, 
   3.543064739172735*^9, {3.54306484354856*^9, 3.543064875108886*^9}, {
   3.543064919883955*^9, 3.543064958463799*^9}, {3.5430654001716957`*^9, 
   3.543065448273386*^9}, 3.5430693336895657`*^9, {3.543845924677206*^9, 
   3.543845976103889*^9}, 3.54522596867283*^9, {3.545226005763097*^9, 
   3.5452260287815313`*^9}, 3.546002808789146*^9, {3.5460028501823263`*^9, 
   3.546002860122488*^9}, 3.546002891755363*^9, 3.546002925521739*^9, {
   3.5461538266630487`*^9, 3.546153835073926*^9}, {3.5461538670647163`*^9, 
   3.5461539795361853`*^9}, {3.546155664682662*^9, 3.546155698260282*^9}, {
   3.546155775902169*^9, 3.5461558112295303`*^9}, {3.5461558497491913`*^9, 
   3.546155857675139*^9}, {3.5471115732151337`*^9, 3.547111593614336*^9}, {
   3.547111654584794*^9, 3.547111668159227*^9}, 3.570224324884205*^9, 
   3.570224412646515*^9, {3.570224461250122*^9, 3.570224481284195*^9}, 
   3.570224549657918*^9, 3.570232901568438*^9, 3.5702337358048487`*^9, 
   3.570234095452153*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tracking", "Subsection",
 CellChangeTimes->{{3.570227553528117*^9, 3.570227554441998*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"xi", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "3"}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"xf", "=", "0.8"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dim", "=", "60"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dx", "=", 
   FractionBox[
    RowBox[{"xf", "-", "xi"}], "dim"]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TT", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"Null", ",", 
     RowBox[{"{", "dim", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"xx", "=", "xi"}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]00", "=", "xi"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]guess", "=", 
    RowBox[{"2.0551788732666325`", "\[VeryThinSpace]", "-", 
     RowBox[{"0.09533427763819255`", " ", "\[ImaginaryI]"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"l", "=", "10"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Omega]guess", "=", 
   RowBox[{"1.40974", "-", 
    RowBox[{"0.0955096", " ", "I"}]}]}], ";", 
  RowBox[{"(*", 
   RowBox[{"l", "=", "7"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"\[Omega]guess", "=", 
   RowBox[{"0.48", "\[VeryThinSpace]", "-", 
    RowBox[{"0.1", " ", "\[ImaginaryI]"}]}]}], ";", 
  RowBox[{"(*", "grav", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"\[Omega]guess", "=", 
   RowBox[{"0.3", "\[VeryThinSpace]", "-", 
    RowBox[{"0.1", " ", "\[ImaginaryI]"}]}]}], ";", 
  RowBox[{"(*", "scal", "*)"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}], "\[IndentingNewLine]", 
  RowBox[{"Monitor", "[", 
   RowBox[{
    RowBox[{"For", "[", 
     RowBox[{
      RowBox[{"j", "=", "1"}], ",", 
      RowBox[{"j", "<", 
       RowBox[{"dim", "+", "1"}]}], ",", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"f4", "[", 
          RowBox[{"y_", "?", "NumericQ"}], "]"}], ":=", 
         RowBox[{
          RowBox[{"LINCOMB", "[", 
           RowBox[{"y", ",", "xx", ",", "10", ",", 
            SuperscriptBox["10", 
             RowBox[{"-", "3"}]], ",", 
            RowBox[{"3", " ", 
             SuperscriptBox["10", "1"]}]}], "]"}], "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"y0n", "=", 
         RowBox[{"y", "/.", 
          RowBox[{
           RowBox[{"FindRoot", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"f4", "[", "y", "]"}], "\[Equal]", "0"}], ",", 
             RowBox[{"{", 
              RowBox[{"y", ",", "\[Omega]guess"}], "}"}]}], 
            RowBox[{"(*", 
             RowBox[{",", 
              RowBox[{"AccuracyGoal", "\[Rule]", "12"}], ",", 
              RowBox[{"PrecisionGoal", "\[Rule]", "12"}]}], "*)"}], "]"}], 
           "[", 
           RowBox[{"[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"check", "=", 
         RowBox[{"Abs", "[", 
          RowBox[{"f4", "[", "y0n", "]"}], "]"}]}], ";", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"TT", "[", 
          RowBox[{"[", "j", "]"}], "]"}], "=", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"N", "[", "xx", "]"}], ",", "y0n", ",", "check"}], "}"}]}],
         ";", "\[IndentingNewLine]", 
        RowBox[{"\[Omega]guess", "=", "y0n"}], ";", "\[IndentingNewLine]", 
        RowBox[{"xx", "=", 
         RowBox[{"xx", "+", "dx"}]}], ";", "\[IndentingNewLine]", 
        RowBox[{"j", "++"}], ";"}], "\[IndentingNewLine]", "}"}]}], "]"}], 
    ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", 
      RowBox[{"N", "[", "xx", "]"}], ",", "y0n", ",", "check"}], "}"}]}], 
   "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.5407225565544453`*^9, 3.5407226132586727`*^9}, {
   3.54072265392922*^9, 3.540722654309886*^9}, {3.54072295994027*^9, 
   3.540722961365369*^9}, {3.540723308974011*^9, 3.5407233200838737`*^9}, {
   3.5407293392218227`*^9, 3.540729342098742*^9}, {3.540729428251597*^9, 
   3.54072946644733*^9}, {3.540729503909698*^9, 3.5407295053659487`*^9}, {
   3.540729614831792*^9, 3.540729628482313*^9}, {3.540729895120841*^9, 
   3.5407298968393583`*^9}, 3.5407303311175528`*^9, {3.540730513162141*^9, 
   3.540730520713378*^9}, {3.5407309613205757`*^9, 3.540730971167066*^9}, 
   3.540731052600148*^9, {3.541227345709585*^9, 3.541227365369323*^9}, {
   3.5412274150128107`*^9, 3.541227415312604*^9}, {3.541227628446604*^9, 
   3.541227631160149*^9}, {3.54122840471576*^9, 3.541228412899972*^9}, {
   3.541230709605042*^9, 3.541230721269291*^9}, {3.541230860530774*^9, 
   3.541230862000626*^9}, {3.541231342891075*^9, 3.541231365297084*^9}, {
   3.541231877579998*^9, 3.541231999667058*^9}, {3.541232538801252*^9, 
   3.541232538978919*^9}, {3.570224588436417*^9, 3.570224675967018*^9}, {
   3.570224823502914*^9, 3.5702248297140703`*^9}, {3.570224933816268*^9, 
   3.570224934733487*^9}, {3.5702276502597113`*^9, 3.570227655751087*^9}, {
   3.570227800642556*^9, 3.570227802402361*^9}, {3.5702333585901623`*^9, 
   3.570233361729741*^9}, {3.5702334703435707`*^9, 3.570233471367923*^9}, 
   3.57023376670082*^9, {3.570233813257642*^9, 3.570233823680091*^9}, {
   3.570233937533441*^9, 3.570233938687195*^9}}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(MachinePrecision\\)\[NoBreak] digits of working precision to \
meet these tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.570224939032114*^9, 3.570227776931776*^9, 
  3.570227812760336*^9, 3.5702334271579037`*^9, 3.57023388950669*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(MachinePrecision\\)\[NoBreak] digits of working precision to \
meet these tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.570224939032114*^9, 3.570227776931776*^9, 
  3.570227812760336*^9, 3.5702334271579037`*^9, 3.570233896878089*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"FindRoot", "::", "lstol"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"The line search decreased the step size to within \
tolerance specified by AccuracyGoal and PrecisionGoal but was unable to find \
a sufficient decrease in the merit function. You may need more than \
\[NoBreak]\\!\\(MachinePrecision\\)\[NoBreak] digits of working precision to \
meet these tolerances. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/FindRoot/lstol\\\", ButtonNote -> \
\\\"FindRoot::lstol\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.570224939032114*^9, 3.570227776931776*^9, 
  3.570227812760336*^9, 3.5702334271579037`*^9, 3.5702339030949373`*^9}],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"General", "::", "stop"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Further output of \[NoBreak]\\!\\(\\*StyleBox[\\(FindRoot \
:: lstol\\), \\\"MessageName\\\"]\\)\[NoBreak] will be suppressed during this \
calculation. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/stop\\\", ButtonNote -> \
\\\"General::stop\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.570224939032114*^9, 3.570227776931776*^9, 
  3.570227812760336*^9, 3.5702334271579037`*^9, 3.570233903126302*^9}],

Cell[BoxData["$Aborted"], "Output",
 CellChangeTimes->{3.570233460911742*^9, 3.570233933500733*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TR", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"TT", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"Re", "[", 
        RowBox[{
         RowBox[{"TT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "TT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TI", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"TT", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"Im", "[", 
        RowBox[{
         RowBox[{"TT", "[", 
          RowBox[{"[", "i", "]"}], "]"}], "[", 
         RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "1", ",", 
       RowBox[{"Length", "[", "TT", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"TR1", "=", "TR"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"TI1", "=", "TI"}], ";"}]}], "Input",
 CellChangeTimes->{{3.570224912234249*^9, 3.570224938211237*^9}, {
  3.5702278066874437`*^9, 3.57022780859748*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", 
  RowBox[{"(*", "**)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"p1", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"TR1", ",", "TR2"}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Mesh", "\[Rule]", "All"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Alpha]/\!\(\*SuperscriptBox[\(M\), \(2\)]\)\>\"", ",", 
          "\"\<\!\(\*SubscriptBox[\(\[Omega]\), \(R\)]\)M\>\""}], "}"}]}], 
       ",", 
       RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"p2", "=", 
     RowBox[{"ListPlot", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Abs", "[", "TI1", "]"}], ",", 
         RowBox[{"Abs", "[", "TI2", "]"}]}], "}"}], ",", 
       RowBox[{"Frame", "\[Rule]", "True"}], ",", 
       RowBox[{"Joined", "\[Rule]", "True"}], ",", 
       RowBox[{"Mesh", "\[Rule]", "All"}], ",", 
       RowBox[{"FrameLabel", "\[Rule]", 
        RowBox[{"{", 
         RowBox[{
         "\"\<\[Alpha]/\!\(\*SuperscriptBox[\(M\), \(2\)]\)\>\"", ",", 
          "\"\<-\!\(\*SubscriptBox[\(\[Omega]\), \(I\)]\)M\>\""}], "}"}]}], 
       ",", 
       RowBox[{"PlotRange", "\[Rule]", "All"}], ",", 
       RowBox[{"Axes", "\[Rule]", "False"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"GraphicsGrid", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"p1", ",", "p2"}], "}"}], "}"}], ",", 
     RowBox[{"ImageSize", "\[Rule]", "700"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.540722882874934*^9, 3.540722919630529*^9}, {
  3.540730172955662*^9, 3.540730181847858*^9}, {3.570224847755109*^9, 
  3.570224978737751*^9}, {3.570225010605791*^9, 3.5702250198816233`*^9}, {
  3.570225051467648*^9, 3.570225065848632*^9}, {3.570228035697439*^9, 
  3.570228043281165*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJw902k81Fscx3HcSrkaWW6UkpsWy5CUJPRTtEjCVJOUNa1jiSRbqaYooQgl
eiFLoYibuClr9jalBnP8538wpJsiDSK5POg8OK/z+PN9/d5/u3qxDkqIiYn5
T76p/2fWwFsrVxuwmVEe0ifgwauBYX8GKxKcVOt3ne/ggQ6vLrHXMgniXK5o
5PXy4Elb+PjB4XRg6Nurl4p4QFms1ObV5YCZ6bq7SyVb4Bzi6CyxyoeurGmv
z6u0gLwC1KDCRxD1b5VXtHELZFjKOcapFMMBu8RUVdcWMOAKRVZhJWDGiVGZ
fq0F6p8UR87oL4UHDpqSUrUtoP2jOsaJWQHRGoKxdslWGIrNo0roSggT7swc
ZLVCmW6CplLcc4iMbHYxutcKl16c9/O1qAFp2ffDfjPawPaIe+Wb8VqIDyzq
yTjaBvOnsRnaBfUQED7Sm1TXBp3JYH/5UCNsoYwWz1Pkw30jjUzh/JfgHDFt
c7MNH07y5L5teP0KghSyCuWD+JBs+Evl9YY3gCnDiOZEPnAlB83HlZtgD7Pj
fu5jPhx+33NMa6gJvnodPH32JR8s09C1vW/egvy6D8gU82GFd9PjsOx3cPmm
OD75jQ/yU/NcaIYI/XjucXEEw9IlEl2O78E6kxXtwUDAb8tTlzP8ANpuWmnp
8xCU3UvfYSrPg6fsOeOWagjS/BJ8Pft4gCZybBK1EISZR91KmtztFl6kUKuH
gCPHLW9IbYWMCXGBuCECa/pU90hQGzC8zJ391iNYlesuvZzNB+H+r0ctzBAo
Brvo7dZF0OjgYZCwBcGYBduOK9UOwXtVpUIsEQgULc/kd7UD1+ZxIMMaQZUQ
0gWlFKx6IHeMzUJw95/VDbMTBCCt5tBxYDeCmnKFkduGNDhm9DDM7BAUL5f5
szCTBvNTTQUiewTZUbNUXshjqOCsSb7ogCBJ9MfKzrMYdM7gq4NOCKL2/zIb
7cPgvVN6kYUrgrNVI2zZfR3Atw64HuqGwEdz8Kh6XQeoOikfzz+EwC26Lxj0
O4HHVC+uPoKAPdJzlX2nE4TbosRqjyHY6tRxx0OmC0I43tOK3BGsm5o/uAty
BEWRNzwRMLWnDr4LqnFk9+HjCFRim/gFbCG86Fm7SNMHwZyxxi/1k9E/9H3F
qBMIJFxrxLFuN9gtXG5x4SSC73VTwd1wKFlCbeEpBN0rSiaLe0ArvW5ujj+C
lvjCdcv8eyDjoecjZiCChvE8KxNhD2wyCay7E4TgqVu28y7WR5AVXx8tfRpB
bmP6CU7ZR5BIW5XIOYMgRS859DyzFxqXDTx7FoLgt98if+NQxneK+NVInl8v
P0gRv+W5Rq2u/RTx6//ywW3RfxTxm+YVuqlSSBG/ZY3Dl0vaKeJXMVtCsekd
RfzeZWxx7q+liF+/PLHy6U8o4ndIjpE/kUURv0ohRufe36CI3/GdJm8TuBTx
W6ET1/nAgyJ+F0TYVLL2UMTvtZyNJovNKeK32u2qrq8xRfwab13t6mVJEb9K
NqnBOr4U8etnPGpg/5AifmVmpQ/P/EERv00BEo7NFgLi95HqwhS1FAHxaxuW
uJY1KiB+Y9slVRO1aOL3E/eqR789Tfwytst+fBpOE7+57hKimCc08euWcCV8
uJcmfuPt1VN2KmHit1jx81yBOSZ+B2MLjEI8MfH7PMRWL/o6Jn4NNdSybudj
4nfxAT69tBoTv/1ztUxON2Di98eO6plaFZj4nQ3Kfj65mPhNjXOR+XQTE7/S
EUzJJRcw8SvSEDWv98bEb6Fdmp2DMyZ+G15D+D5bTPz2RXXVSU32/PYbYaA9
YLoWE7/LVpkltWhj4nd7+6WlD5dg4vdEwwLO3QWY+K1ovL4m+S9M/J4dyRsL
kMHEr2ZHVZ+yFCZ+fS6WVXOmY+J3o97nCZY4Jn65Q/5ipeM08cvc9iLt1ihN
/IZoxgj4wzTxG9G1TemEiCZ+S2/+rN89SBO/bp6hgsABmvi971nVz/tKE781
my3fHf1Cw/8LktzY
       "], {{{}, {}, 
         {Hue[0.67, 0.6, 0.6], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 54, 55, 56, 57, 58, 59, 60}]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], 
          LineBox[{61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75,
            76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 
           92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 
           107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 
           120}]}}, {
         {Hue[0.67, 0.6, 0.6], 
          PointBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17,
            18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
           34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
            51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 
           67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
            84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
           100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 
           113, 114, 115, 116, 117, 118, 119, 120}]}, {}, {}, {}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{0, 0.4},
      Frame->True,
      FrameLabel->{
        FormBox[
        "\"\[Alpha]/\\!\\(\\*SuperscriptBox[\\(M\\), \\(2\\)]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"\\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(R\\)]\\)M\"", 
         TraditionalForm]},
      PlotRange->{{0., 0.7866833333333325}, {0.3730424640235457, 
       0.5559679217046476}},
      PlotRangeClipping->True,
      PlotRangePadding->{
        Scaled[0.02], 
        Scaled[0.02]}], {192., -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[GraphicsComplexBox[CompressedData["
1:eJxF03s4lHkUB3Cm4qmIXLa2Wj12RclIQqIcnvRgNVbSLBspCbklRWyyuRQJ
KalFLoVxSe7zel8mM/OSXEqG3Ma4jjFasSu5tNIuf/Trj/Oc/855vuc5H1XX
C3bnKBISEsHLtdI/F0y301xtgd5x06yjBIPW6fngDXbxsEpjkPfzUwy0uxvT
3lk/AhOP+uMbMzGo5scunZvPgcUp+7tVtzEYsNpL7W58Ctafr1w8EoBBuMBb
W41WBlsU9imftMdAUQkaBMxKiMmYk6LrYZBrrXAqWQWH8v2SZf7KGOyPFM3S
omvgIIU207XIhKZqPF7qn1qYtM85UfaeCdRPL+65aHHhbGsCpj/FhLn7JQM1
QyQosZNdhNIYsHVSNDcn10N3iYWV5mEMYl5FBF22aoA6aml5dhEGxzx9yLal
l3DqzwmPc/ZVsGU1fQO1vAna8jKSTY7gIMyE3265twArV75tyIuAIuNdDNGW
1xARr89SS6qGwG6FD2ZvWkHRWHqtS3oNZB74ovLGrA1U5EcUnKNYECk9Y760
lQfZnNbTdNpz8OgUe+2e4wGREbG5+MtzsM4WJDq2tcN/KrGhSem1sOciD4su
7ACnnvt9tVQ2KK6cJ+otSPIO+lWWsWFepoYyeqoTqGmyLgnKHOjjl+xUONAF
bTMVgbE0DrDzc2xMFbshK08YvjecA9lBKZf9JruBws7Y3VnKgWjzhNRHL3vA
taJXiy3ggLdCJKf5cS+8yZ/ON1zDhV+GrowtXOXDYMiRHbc0ubCv2EdGg94H
Qlpu09xRLmwKPaN7QkcAuoFMQb0PFxat6A6R6/qBEUrZuC+WC4ObrMPKRvtB
s8+l9/dcLtSJIGewdgAqQnxy2mq5kFeh1yybMgjcVQ42nl1caOAoLaQfGIK+
7+ya3d9zAdeQW89kDMEFFos+I0FCYcJalVeKw8CTfRyto0TCo9lVe4XXh6FK
/pGtqToJCU5fDv87OQx33qtzjPaTcL1ugb7x5AhUDzD8DS1ICNCcOb+zcQTs
On0+HqWT4HZ3MhT0haC0OUo2wY0E+oL4Dv2JEOLES63rA0iwdBl54is3CvP8
XfFdYSQYrZw/dBQWr0T0fI4lQYu68vCjMMWx9I99QILKfV5fOV0E0aoUg7jH
JMgvtkw1LYeelvCylCkigeLaIDmsMwZLRTKmyhgJHxtXAo9B2kHLiWI2CWN7
apYTi+HsMRZb2EhCzwOmkXqwGNIXnNJxHgnNSyW0QyIxyDe+UtXjk8ByKzxt
bzcOx4rs5JxGSChuybnkzR4HLqHba/wXCVm6mTcjtN6BYtTh7e3TJHz16yg4
I5k2giO/1kkvfmofwJHfrkibdQ5vceRXXfgxrI/Ekd8H4Yn+7QU48ju+Y3vS
xRgc+TUM092d6Ywjv21Z/MkBDRz53daela8rqkJ+qVJXd4rvVSG/ciYpY6bU
KuQXv5NuPFH8ze+HG3Zp0vLf/FaRAstRcyby+86tulDKpBL5DfTs/1A8XY78
jmjXjjkHlSG/z1U9FXMkS5HfuOAbicn+z5BfjedFL89YPEV+ncJHfdujCpDf
1MCC5Ogf85FfqrWevMfWPOQ33D/6Id2Hgfw+pNWYblZiIL/XI1i3lRQZyO+T
VAcpY28G8ttoljjw7/Y85Dd0dlzNwiAf+RUPh2jGVhYgv7Jef+caPHmK/Nqy
gha3SRUjv2Naa1TS/EuRX2eDkmY/+XLkV+RiWFdKViC/h669zu+nMZFfRo3v
CBaJIb+Xs2/wBa5VyG8jdbb5V0kc+fWjMtbHXMKR3/Nq2oxPDTjyq9LkTtFb
TSC/p+tfpjbpEMivm4h3PMuWQH7rj0oM5boTyO/NCbGmeiCB/JZJ7dafu0Yg
v763wwriIgjkt1DIxWWjCORX/FbU6hhJIL8Otskt34cTyG+ATDenZXneV79G
ZkPBTSEE8ptBiTB3Xd7/1a9FlpdNqT+B/K7j1zFF3gTy6+D6rO8HDwL5zc2p
wE67EsjvXNwfekXOxDe/HeqiPY4E/A/s9tpY
       "], {{{}, {}, 
         {Hue[0.67, 0.6, 0.6], 
          LineBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 
           18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34,
            35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 
           51, 52, 53, 54, 55, 56, 57, 58, 59, 60}]}, 
         {Hue[0.9060679774997897, 0.6, 0.6], 
          LineBox[{61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75,
            76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 
           92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 
           107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 
           120}]}}, {
         {Hue[0.67, 0.6, 0.6], 
          PointBox[{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17,
            18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 
           34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50,
            51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 65, 66, 
           67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83,
            84, 85, 86, 87, 88, 89, 90, 91, 92, 93, 94, 95, 96, 97, 98, 99, 
           100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 
           113, 114, 115, 116, 117, 118, 119, 120}]}, {}, {}, {}}}],
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      AxesOrigin->{0, 0.06},
      Frame->True,
      FrameLabel->{
        FormBox[
        "\"\[Alpha]/\\!\\(\\*SuperscriptBox[\\(M\\), \\(2\\)]\\)\"", 
         TraditionalForm], 
        FormBox[
        "\"-\\!\\(\\*SubscriptBox[\\(\[Omega]\\), \\(I\\)]\\)M\"", 
         TraditionalForm]},
      PlotRange->{All, All},
      PlotRangeClipping->True,
      PlotRangePadding->{Automatic, Automatic}], {576., -116.80842387373012`},
      ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  ImageSize->700,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.54072288501126*^9, 3.5407229202687187`*^9}, 
   3.540723264294574*^9, 3.540723567338957*^9, 3.5407298037022867`*^9, 
   3.540729955809334*^9, 3.540730190486145*^9, 3.5407304341339817`*^9, 
   3.5407306989704123`*^9, 3.540731018957061*^9, 3.540731101232809*^9, 
   3.541227571522785*^9, 3.541228299584569*^9, 3.5412302995561934`*^9, 
   3.541231241121996*^9, 3.570224899491914*^9, {3.5702249973637466`*^9, 
   3.570225021567658*^9}, {3.570225052520591*^9, 3.5702250665807867`*^9}, 
   3.570227786808202*^9, 3.5702280044598637`*^9, {3.57022803639612*^9, 
   3.570228043595442*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Higher-l", "Subsection",
 CellChangeTimes->{{3.5702329049238167`*^9, 3.570232906593246*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]guess", "=", 
    RowBox[{"0.48", "\[VeryThinSpace]", "-", 
     RowBox[{"0.1", " ", "\[ImaginaryI]"}]}]}], ";"}], 
  RowBox[{"(*", "grav", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Omega]guess", "=", 
    RowBox[{"0.3", "\[VeryThinSpace]", "-", 
     RowBox[{"0.1", " ", "\[ImaginaryI]"}]}]}], ";", 
   RowBox[{"(*", "scal", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"\[Omega]guess", "=", 
    RowBox[{"1.40974", "-", 
     RowBox[{"0.0955096", " ", "I"}]}]}], ";", 
   RowBox[{"(*", 
    RowBox[{"l", "=", "7"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{"\[Omega]guess", "=", 
    RowBox[{"1.9916474515518394`", "\[VeryThinSpace]", "-", 
     RowBox[{"0.287911944390142`", " ", "I"}]}]}], ";"}], 
  RowBox[{"(*", 
   RowBox[{"l", "=", "10"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Omega]guess", "=", 
   RowBox[{"2", "\[VeryThinSpace]", "-", 
    RowBox[{"0.3`", " ", "I"}]}]}], ";", 
  RowBox[{"(*", 
   RowBox[{"l", "=", "10"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"\[Omega]guess", "=", 
     RowBox[{"0.7337751980725775`", "\[VeryThinSpace]", "-", 
      RowBox[{"0.127070807565408`", " ", "\[ImaginaryI]"}]}]}], ";"}], 
   RowBox[{"(*", "scal", "*)"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**", "**",
     "**", "**", "**", "**", "**", "**", "**", "**", "**"}], "*****)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"f4", "[", 
    RowBox[{"y_", "?", "NumericQ"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"LINCOMB", "[", 
     RowBox[{"y", ",", "0", ",", "10", ",", 
      RowBox[{"1", " ", 
       SuperscriptBox["10", 
        RowBox[{"-", "3"}]]}], ",", "40"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"y0n", "=", 
  RowBox[{"y", "/.", 
   RowBox[{
    RowBox[{"FindRoot", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"f4", "[", "y", "]"}], "\[Equal]", "0"}], ",", 
      RowBox[{"{", 
       RowBox[{"y", ",", "\[Omega]guess"}], "}"}]}], 
     RowBox[{"(*", 
      RowBox[{",", 
       RowBox[{"AccuracyGoal", "\[Rule]", "2"}], ",", 
       RowBox[{"PrecisionGoal", "\[Rule]", "12"}]}], "*)"}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"Abs", "[", 
  RowBox[{"f4", "[", "y0n", "]"}], "]"}]}], "Input",
 CellChangeTimes->{{3.540640409040543*^9, 3.54064042545057*^9}, {
   3.5406404559532757`*^9, 3.540640487057073*^9}, {3.540640549901157*^9, 
   3.540640550826927*^9}, {3.540640670583375*^9, 3.540640730154347*^9}, {
   3.540640761378539*^9, 3.540640766635561*^9}, {3.54064080069508*^9, 
   3.540640811555477*^9}, {3.540640953538796*^9, 3.540641158503352*^9}, {
   3.540641406374235*^9, 3.540641420061475*^9}, {3.5406415621182947`*^9, 
   3.540641569919055*^9}, {3.540641631640499*^9, 3.540641637102079*^9}, {
   3.540641688928248*^9, 3.54064170139394*^9}, {3.540644521465933*^9, 
   3.540644530191144*^9}, {3.540645144377039*^9, 3.54064515837221*^9}, 
   3.540645224545512*^9, {3.540645255680593*^9, 3.540645401137281*^9}, 
   3.5406460961984158`*^9, 3.540646151322596*^9, {3.540647344014057*^9, 
   3.54064739507596*^9}, {3.540647434949544*^9, 3.5406474358391857`*^9}, {
   3.540704631477262*^9, 3.5407047906977777`*^9}, {3.540704821367272*^9, 
   3.540704821515333*^9}, {3.5407057899602337`*^9, 3.540705795885453*^9}, {
   3.540705833299431*^9, 3.540705979212254*^9}, 3.540708083680633*^9, {
   3.540708142606962*^9, 3.5407081713934813`*^9}, 3.5407082053016357`*^9, {
   3.540708246063858*^9, 3.54070825974714*^9}, 3.540710346717804*^9, {
   3.540719329126381*^9, 3.540719392017159*^9}, 3.540719471892127*^9, 
   3.5407195135287247`*^9, {3.5407199784120693`*^9, 3.540720054229109*^9}, {
   3.540720550501946*^9, 3.540720598311174*^9}, {3.540721070234262*^9, 
   3.540721264573799*^9}, {3.540721301377472*^9, 3.540721428537983*^9}, {
   3.5411602253891172`*^9, 3.541160245977396*^9}, {3.541163003433552*^9, 
   3.541163014330926*^9}, {3.541226442436843*^9, 3.541226493677372*^9}, {
   3.541226575793952*^9, 3.541226583845286*^9}, {3.541226632522155*^9, 
   3.5412266406794157`*^9}, 3.541226675956039*^9, {3.5412270952361603`*^9, 
   3.5412271592125177`*^9}, {3.54122722712033*^9, 3.541227238468721*^9}, {
   3.541227273309559*^9, 3.541227275078491*^9}, {3.541233170847823*^9, 
   3.541233251989602*^9}, {3.541233352279415*^9, 3.541233371904509*^9}, {
   3.541233409153061*^9, 3.541233547699046*^9}, 3.541243680562804*^9, {
   3.541243719831621*^9, 3.541243722104228*^9}, {3.541244240419671*^9, 
   3.5412442419414062`*^9}, 3.54126045575*^9, 3.541260493477393*^9, 
   3.5412605533217382`*^9, {3.5412606179128323`*^9, 3.541260621707213*^9}, 
   3.541260719629475*^9, 3.541307705331996*^9, 3.541307773177146*^9, 
   3.541308133840995*^9, {3.541308390703692*^9, 3.5413084006147223`*^9}, {
   3.5413087967647247`*^9, 3.541308797803729*^9}, {3.541512034055758*^9, 
   3.541512041696727*^9}, {3.5415122329120417`*^9, 3.541512236927578*^9}, {
   3.5415122867387657`*^9, 3.541512294215941*^9}, {3.541512385678061*^9, 
   3.541512389754486*^9}, 3.5415124710581636`*^9, {3.541512521573166*^9, 
   3.541512536683296*^9}, {3.541512648477215*^9, 3.5415126676066303`*^9}, 
   3.541512745423221*^9, {3.5415127994967537`*^9, 3.541512806998419*^9}, {
   3.541512897746273*^9, 3.5415128997707872`*^9}, {3.541512983229661*^9, 
   3.541512985398868*^9}, {3.541513044906458*^9, 3.5415130492002487`*^9}, {
   3.541513126566976*^9, 3.541513134147285*^9}, {3.541569762877513*^9, 
   3.541569771371152*^9}, {3.54157005922287*^9, 3.541570060332726*^9}, 
   3.5415702070915117`*^9, {3.541570451682013*^9, 3.541570455572055*^9}, {
   3.5415707042909803`*^9, 3.541570710173533*^9}, 3.541571038621105*^9, {
   3.541575845593234*^9, 3.541575858287315*^9}, {3.541575941090598*^9, 
   3.5415759424833517`*^9}, {3.5415760716092663`*^9, 
   3.5415760777720633`*^9}, {3.5415762051711063`*^9, 3.541576206139612*^9}, {
   3.541576360756578*^9, 3.5415763647092857`*^9}, {3.541576435542611*^9, 
   3.541576440550478*^9}, {3.541576709909539*^9, 3.541576713986745*^9}, {
   3.5415769303082857`*^9, 3.5415769347440243`*^9}, 3.541577114046023*^9, {
   3.543064103969022*^9, 3.543064137038541*^9}, {3.543064167122015*^9, 
   3.54306417793703*^9}, {3.543064252049169*^9, 3.5430642523044453`*^9}, {
   3.5430644625642023`*^9, 3.5430645108237743`*^9}, {3.5430645826113853`*^9, 
   3.5430645831730328`*^9}, {3.543064737883684*^9, 3.5430647382596693`*^9}, {
   3.543064841095715*^9, 3.543064874402994*^9}, {3.543064918620253*^9, 
   3.543064957614048*^9}, {3.543065399207594*^9, 3.543065447666004*^9}, 
   3.543069333186558*^9, {3.5438459175387077`*^9, 3.543845975635757*^9}, {
   3.545226027447884*^9, 3.5452260275789337`*^9}, {3.546002800953768*^9, 
   3.546002890265009*^9}, {3.546002923002837*^9, 3.546002924028316*^9}, {
   3.546153814172776*^9, 3.546153834565074*^9}, {3.5461538665403547`*^9, 
   3.546153978945874*^9}, {3.546155662285247*^9, 3.546155697882069*^9}, {
   3.546155785430122*^9, 3.546155810693411*^9}, {3.546155853398089*^9, 
   3.546155857196891*^9}, {3.546247734209504*^9, 3.546247734539815*^9}, {
   3.5471115640884743`*^9, 3.547111592767848*^9}, {3.547111667516321*^9, 
   3.54711166778428*^9}, {3.570224282115739*^9, 3.5702243220009413`*^9}, {
   3.570224383066101*^9, 3.570224393712757*^9}, {3.570224540537096*^9, 
   3.570224558905892*^9}, 3.570227534552004*^9, {3.570232920864751*^9, 
   3.570232920982204*^9}, {3.570233039423953*^9, 3.57023304321117*^9}, 
   3.570233178432125*^9, {3.570233318265422*^9, 3.5702333449111137`*^9}, {
   3.570233739699419*^9, 3.570233743202908*^9}, {3.570234105272028*^9, 
   3.5702341288133574`*^9}, {3.570234166857644*^9, 3.5702342889331627`*^9}, {
   3.570234319915505*^9, 3.5702343449623213`*^9}, {3.570234382730154*^9, 
   3.5702343892323227`*^9}}],

Cell[BoxData[
 RowBox[{"2.049253901548875`", "\[VeryThinSpace]", "-", 
  RowBox[{"0.10087959554926164`", " ", "\[ImaginaryI]"}]}]], "Output",
 CellChangeTimes->{{3.540641038294402*^9, 3.540641159047176*^9}, {
   3.5406413913051767`*^9, 3.5406414205621967`*^9}, 3.540641572370143*^9, 
   3.540641638959957*^9, 3.540644530834536*^9, {3.5406451472096453`*^9, 
   3.540645159146916*^9}, 3.540645225221682*^9, {3.5406452571184597`*^9, 
   3.540645329667535*^9}, {3.5406453672538843`*^9, 3.540645401610221*^9}, 
   3.540646096919957*^9, 3.540646152833391*^9, {3.540647372743726*^9, 
   3.540647398725678*^9}, {3.540704669808668*^9, 3.540704714520185*^9}, {
   3.540704775871418*^9, 3.540704791302834*^9}, 3.540704821914407*^9, 
   3.540705796653615*^9, 3.540705833686388*^9, {3.540705872654077*^9, 
   3.54070597965035*^9}, 3.540706951011766*^9, 3.540708090408354*^9, {
   3.540708152286853*^9, 3.5407081734427013`*^9}, 3.540708206185439*^9, {
   3.540708252518714*^9, 3.540708260623263*^9}, 3.540710347092958*^9, {
   3.5407193445296392`*^9, 3.540719384350062*^9}, 3.540719466171034*^9, {
   3.540719508506701*^9, 3.540719518356738*^9}, {3.540719987372149*^9, 
   3.540720054804085*^9}, {3.540720551521158*^9, 3.540720598984251*^9}, {
   3.540721075899622*^9, 3.540721265017913*^9}, {3.54072131924723*^9, 
   3.54072142365228*^9}, {3.5411602271140413`*^9, 3.541160246547501*^9}, 
   3.541160646493908*^9, 3.541161104337887*^9, 3.5411619087907343`*^9, {
   3.5411630043077497`*^9, 3.5411630152530518`*^9}, {3.541226425232889*^9, 
   3.5412264943197327`*^9}, {3.541226576373008*^9, 3.541226587141582*^9}, {
   3.541226633951749*^9, 3.5412266410664988`*^9}, 3.54122668004743*^9, {
   3.5412270971763363`*^9, 3.5412271599044123`*^9}, {3.541227232213773*^9, 
   3.541227238867959*^9}, 3.541227275963809*^9, 3.5412315829072237`*^9, {
   3.5412331754791927`*^9, 3.541233253664906*^9}, {3.541233347245007*^9, 
   3.541233372385597*^9}, {3.541233417317051*^9, 3.541233540124751*^9}, 
   3.541243640137169*^9, 3.541243681595481*^9, 3.541243723112852*^9, 
   3.54124424265422*^9, 3.5412604573886547`*^9, 3.5412604960465307`*^9, 
   3.541260553839506*^9, 3.541260622440199*^9, 3.5413076200194674`*^9, 
   3.541307708177421*^9, 3.541307774057857*^9, 3.541308135816407*^9, 
   3.541308401031447*^9, 3.541308798906425*^9, 3.541512046992133*^9, 
   3.5415122378700542`*^9, 3.54151229477452*^9, 3.541512390865068*^9, 
   3.541512476730919*^9, 3.5415125373524313`*^9, 3.541512664273636*^9, 
   3.541512747491485*^9, 3.541512807336828*^9, 3.5415129011262712`*^9, 
   3.541512986925935*^9, 3.541513053744988*^9, 3.541513135067745*^9, 
   3.541569772404182*^9, 3.5415700623209667`*^9, 3.541570297220149*^9, 
   3.5415704571393633`*^9, 3.541570711128563*^9, 3.541575859522731*^9, 
   3.541575945972968*^9, 3.541576078882113*^9, 3.541576208347329*^9, 
   3.541576366719902*^9, 3.5415764409578123`*^9, 3.541576717982485*^9, 
   3.541576935941092*^9, 3.543064254208578*^9, 3.5430645177082043`*^9, 
   3.543064739172735*^9, {3.54306484354856*^9, 3.543064875108886*^9}, {
   3.543064919883955*^9, 3.543064958463799*^9}, {3.5430654001716957`*^9, 
   3.543065448273386*^9}, 3.5430693336895657`*^9, {3.543845924677206*^9, 
   3.543845976103889*^9}, 3.54522596867283*^9, {3.545226005763097*^9, 
   3.5452260287815313`*^9}, 3.546002808789146*^9, {3.5460028501823263`*^9, 
   3.546002860122488*^9}, 3.546002891755363*^9, 3.546002925521739*^9, {
   3.5461538266630487`*^9, 3.546153835073926*^9}, {3.5461538670647163`*^9, 
   3.5461539795361853`*^9}, {3.546155664682662*^9, 3.546155698260282*^9}, {
   3.546155775902169*^9, 3.5461558112295303`*^9}, {3.5461558497491913`*^9, 
   3.546155857675139*^9}, {3.5471115732151337`*^9, 3.547111593614336*^9}, {
   3.547111654584794*^9, 3.547111668159227*^9}, 3.570224324884205*^9, 
   3.570224412646515*^9, {3.570224461250122*^9, 3.570224481284195*^9}, 
   3.570224549657918*^9, 3.570232901568438*^9, 3.570233008781619*^9, 
   3.570233124467284*^9, {3.570233315861753*^9, 3.5702333491633*^9}, 
   3.570233766968251*^9, 3.570234123178199*^9, 3.570234158201007*^9, {
   3.570234194194242*^9, 3.570234277004737*^9}, {3.570234314789435*^9, 
   3.5702343605286417`*^9}, 3.570234412871561*^9}],

Cell[BoxData["5.404771110668931`*^-10"], "Output",
 CellChangeTimes->{{3.540641038294402*^9, 3.540641159047176*^9}, {
   3.5406413913051767`*^9, 3.5406414205621967`*^9}, 3.540641572370143*^9, 
   3.540641638959957*^9, 3.540644530834536*^9, {3.5406451472096453`*^9, 
   3.540645159146916*^9}, 3.540645225221682*^9, {3.5406452571184597`*^9, 
   3.540645329667535*^9}, {3.5406453672538843`*^9, 3.540645401610221*^9}, 
   3.540646096919957*^9, 3.540646152833391*^9, {3.540647372743726*^9, 
   3.540647398725678*^9}, {3.540704669808668*^9, 3.540704714520185*^9}, {
   3.540704775871418*^9, 3.540704791302834*^9}, 3.540704821914407*^9, 
   3.540705796653615*^9, 3.540705833686388*^9, {3.540705872654077*^9, 
   3.54070597965035*^9}, 3.540706951011766*^9, 3.540708090408354*^9, {
   3.540708152286853*^9, 3.5407081734427013`*^9}, 3.540708206185439*^9, {
   3.540708252518714*^9, 3.540708260623263*^9}, 3.540710347092958*^9, {
   3.5407193445296392`*^9, 3.540719384350062*^9}, 3.540719466171034*^9, {
   3.540719508506701*^9, 3.540719518356738*^9}, {3.540719987372149*^9, 
   3.540720054804085*^9}, {3.540720551521158*^9, 3.540720598984251*^9}, {
   3.540721075899622*^9, 3.540721265017913*^9}, {3.54072131924723*^9, 
   3.54072142365228*^9}, {3.5411602271140413`*^9, 3.541160246547501*^9}, 
   3.541160646493908*^9, 3.541161104337887*^9, 3.5411619087907343`*^9, {
   3.5411630043077497`*^9, 3.5411630152530518`*^9}, {3.541226425232889*^9, 
   3.5412264943197327`*^9}, {3.541226576373008*^9, 3.541226587141582*^9}, {
   3.541226633951749*^9, 3.5412266410664988`*^9}, 3.54122668004743*^9, {
   3.5412270971763363`*^9, 3.5412271599044123`*^9}, {3.541227232213773*^9, 
   3.541227238867959*^9}, 3.541227275963809*^9, 3.5412315829072237`*^9, {
   3.5412331754791927`*^9, 3.541233253664906*^9}, {3.541233347245007*^9, 
   3.541233372385597*^9}, {3.541233417317051*^9, 3.541233540124751*^9}, 
   3.541243640137169*^9, 3.541243681595481*^9, 3.541243723112852*^9, 
   3.54124424265422*^9, 3.5412604573886547`*^9, 3.5412604960465307`*^9, 
   3.541260553839506*^9, 3.541260622440199*^9, 3.5413076200194674`*^9, 
   3.541307708177421*^9, 3.541307774057857*^9, 3.541308135816407*^9, 
   3.541308401031447*^9, 3.541308798906425*^9, 3.541512046992133*^9, 
   3.5415122378700542`*^9, 3.54151229477452*^9, 3.541512390865068*^9, 
   3.541512476730919*^9, 3.5415125373524313`*^9, 3.541512664273636*^9, 
   3.541512747491485*^9, 3.541512807336828*^9, 3.5415129011262712`*^9, 
   3.541512986925935*^9, 3.541513053744988*^9, 3.541513135067745*^9, 
   3.541569772404182*^9, 3.5415700623209667`*^9, 3.541570297220149*^9, 
   3.5415704571393633`*^9, 3.541570711128563*^9, 3.541575859522731*^9, 
   3.541575945972968*^9, 3.541576078882113*^9, 3.541576208347329*^9, 
   3.541576366719902*^9, 3.5415764409578123`*^9, 3.541576717982485*^9, 
   3.541576935941092*^9, 3.543064254208578*^9, 3.5430645177082043`*^9, 
   3.543064739172735*^9, {3.54306484354856*^9, 3.543064875108886*^9}, {
   3.543064919883955*^9, 3.543064958463799*^9}, {3.5430654001716957`*^9, 
   3.543065448273386*^9}, 3.5430693336895657`*^9, {3.543845924677206*^9, 
   3.543845976103889*^9}, 3.54522596867283*^9, {3.545226005763097*^9, 
   3.5452260287815313`*^9}, 3.546002808789146*^9, {3.5460028501823263`*^9, 
   3.546002860122488*^9}, 3.546002891755363*^9, 3.546002925521739*^9, {
   3.5461538266630487`*^9, 3.546153835073926*^9}, {3.5461538670647163`*^9, 
   3.5461539795361853`*^9}, {3.546155664682662*^9, 3.546155698260282*^9}, {
   3.546155775902169*^9, 3.5461558112295303`*^9}, {3.5461558497491913`*^9, 
   3.546155857675139*^9}, {3.5471115732151337`*^9, 3.547111593614336*^9}, {
   3.547111654584794*^9, 3.547111668159227*^9}, 3.570224324884205*^9, 
   3.570224412646515*^9, {3.570224461250122*^9, 3.570224481284195*^9}, 
   3.570224549657918*^9, 3.570232901568438*^9, 3.570233008781619*^9, 
   3.570233124467284*^9, {3.570233315861753*^9, 3.5702333491633*^9}, 
   3.570233766968251*^9, 3.570234123178199*^9, 3.570234158201007*^9, {
   3.570234194194242*^9, 3.570234277004737*^9}, {3.570234314789435*^9, 
   3.5702343605286417`*^9}, 3.570234413042241*^9}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 712},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 470, 10, 66, "Subtitle"],
Cell[CellGroupData[{
Cell[1074, 36, 167, 2, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[1266, 42, 3815, 120, 335, "Input"],
Cell[5084, 164, 1657, 53, 57, "Output"],
Cell[6744, 219, 2178, 68, 76, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8971, 293, 236, 5, 28, "Subsubsection"],
Cell[9210, 300, 1845, 57, 209, "Input"],
Cell[CellGroupData[{
Cell[11080, 361, 4495, 125, 250, "Input"],
Cell[15578, 488, 935, 13, 70, "Output"],
Cell[16516, 503, 935, 13, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[17488, 521, 391, 12, 35, "Input"],
Cell[17882, 535, 487, 13, 70, "Output"]
}, Open  ]],
Cell[18384, 551, 566, 14, 48, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[18987, 570, 186, 4, 22, "Subsubsection"],
Cell[CellGroupData[{
Cell[19198, 578, 1271, 35, 148, "Input"],
Cell[20472, 615, 3223, 88, 70, "Output"],
Cell[23698, 705, 3638, 108, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27373, 818, 3778, 113, 307, "Input"],
Cell[31154, 933, 683, 10, 70, "Output"],
Cell[31840, 945, 681, 10, 70, "Output"]
}, Open  ]],
Cell[32536, 958, 453, 12, 48, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[33026, 975, 174, 2, 22, "Subsubsection"],
Cell[CellGroupData[{
Cell[33225, 981, 6496, 170, 362, "Input"],
Cell[39724, 1153, 683, 10, 70, "Output"]
}, Open  ]],
Cell[40422, 1166, 408, 10, 48, "Input"],
Cell[CellGroupData[{
Cell[40855, 1180, 129, 2, 29, "Input"],
Cell[40987, 1184, 190, 3, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[41226, 1193, 99, 1, 29, "Subsection"],
Cell[41328, 1196, 10573, 275, 642, "Input"],
Cell[CellGroupData[{
Cell[51926, 1475, 550, 14, 53, "Input"],
Cell[52479, 1491, 445, 10, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[52961, 1506, 101, 1, 28, "Subsubsection"],
Cell[53065, 1509, 5280, 115, 570, "Input"],
Cell[CellGroupData[{
Cell[58370, 1628, 498, 11, 35, "Input"],
Cell[58871, 1641, 1672, 26, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60592, 1673, 149, 2, 28, "Subsubsection"],
Cell[CellGroupData[{
Cell[60766, 1679, 6686, 115, 142, "Input"],
Cell[67455, 1796, 3951, 55, 29, "Output"],
Cell[71409, 1853, 3860, 53, 32, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[75330, 1913, 96, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[75451, 1918, 5372, 124, 522, "Input"],
Cell[80826, 2044, 780, 14, 58, "Message"],
Cell[81609, 2060, 781, 14, 58, "Message"],
Cell[82393, 2076, 783, 14, 58, "Message"],
Cell[83179, 2092, 625, 12, 23, "Message"],
Cell[83807, 2106, 99, 1, 29, "Output"]
}, Open  ]],
Cell[83921, 2110, 1155, 38, 48, "Input"],
Cell[85079, 2150, 259, 6, 48, "Input"],
Cell[CellGroupData[{
Cell[85363, 2160, 2029, 51, 111, "Input"],
Cell[87395, 2213, 8885, 156, 245, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[96329, 2375, 98, 1, 37, "Subsection"],
Cell[CellGroupData[{
Cell[96452, 2380, 7937, 140, 214, "Input"],
Cell[104392, 2522, 4187, 58, 29, "Output"],
Cell[108582, 2582, 4096, 56, 32, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
