(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 7.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    112917,       3203]
NotebookOptionsPosition[    109214,       3084]
NotebookOutlinePosition[    109541,       3099]
CellTagsIndexPosition[    109498,       3096]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Massive Klein-Gordon perturbations of a Kerr BH to second order in the spin\
\n",
 StyleBox["Reference: Paolo Pani, \[OpenCurlyDoubleQuote]Advanced methods in \
Black-Hole Perturbation Theory\[CloseCurlyDoubleQuote] (2013)",
  FontSize->12]
}], "Subtitle",
 CellChangeTimes->{{3.537166800678636*^9, 3.537166824376327*^9}, 
   3.570721246663713*^9, {3.571072490810357*^9, 3.571072492736107*^9}}],

Cell[TextData[StyleBox["Background:", "Section"]], "Subtitle",
 CellChangeTimes->{{3.4748662984784307`*^9, 3.474866318276967*^9}, {
  3.49682537622365*^9, 3.496825382669928*^9}, {3.516876275160224*^9, 
  3.516876279587028*^9}, {3.5355440086694717`*^9, 3.535544016131024*^9}, {
  3.570721366769459*^9, 3.570721375724918*^9}, {3.5707214260030746`*^9, 
  3.5707214286436462`*^9}, {3.570721486927219*^9, 3.570721487845373*^9}, {
  3.570721861181693*^9, 3.570721865943096*^9}, {3.570722916773744*^9, 
  3.570722920873625*^9}}],

Cell["We take the Kerr metric:", "Text",
 CellChangeTimes->{{3.5707212815918007`*^9, 3.5707212856392*^9}}],

Cell[BoxData[{
 RowBox[{"ClearAll", "[", 
  RowBox[{
  "GM0", ",", "x", ",", "g", ",", "\[Phi]", ",", "\[Phi]0", ",", 
   "\[CapitalLambda]", ",", "\[CapitalPsi]", ",", "\[Alpha]", ",", "\[Gamma]",
    ",", "Y", ",", "\[CapitalSigma]", ",", "\[CapitalDelta]", ",", "NN", ",", 
   "\[Omega]", ",", "\[CapitalDelta]", ",", "\[CapitalSigma]", ",", "gff", 
   ",", "gtt", ",", "\[Phi]", ",", "M", ",", "F", ",", "V", ",", "f0", ",", 
   "f1", ",", "f2", ",", "f3", ",", "f4", ",", "\[CapitalOmega]", ",", "A", 
   ",", "\[Phi]", ",", "B", ",", "\[Zeta]", ",", "\[Phi]", ",", 
   "\[CapitalPhi]1"}], "]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[LessEqual]", "\[Pi]"}], ",", 
     RowBox[{"J", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"NN", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"rh", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"X", "\[GreaterEqual]", "0"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"x", "=", 
   RowBox[{"{", 
    RowBox[{"t", ",", "r", ",", "\[Theta]", ",", "\[CurlyPhi]"}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[CapitalSigma]", "=", 
   RowBox[{
    SuperscriptBox["r", "2"], "+", 
    RowBox[{
     SuperscriptBox["\[Epsilon]a", "2"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox["J", "M"], ")"}], "2"], 
     SuperscriptBox[
      RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]", "=", 
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     RowBox[{
      SuperscriptBox["\[Epsilon]a", "2"], 
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox["J", "M"], ")"}], "2"]}], "-", 
     RowBox[{"2", "M", " ", "r"}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"gdd0", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"1", "-", 
           FractionBox[
            RowBox[{"2", " ", "M", " ", "r"}], "\[CapitalSigma]"]}], ")"}]}], 
        ",", "0", ",", "0", ",", 
        RowBox[{
         RowBox[{"-", "2"}], " ", "M", " ", "\[Epsilon]a", " ", 
         FractionBox["r", "\[CapitalSigma]"], 
         FractionBox["J", "M"], 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", 
        FractionBox["\[CapitalSigma]", "\[CapitalDelta]"], ",", "0", ",", 
        "0"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "\[CapitalSigma]", ",", "0"}], "}"}], ",", 
      
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "M", " ", "\[Epsilon]a", " ", 
         FractionBox["r", "\[CapitalSigma]"], 
         FractionBox["J", "M"], 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], ",", "0", ",", "0", 
        ",", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             SuperscriptBox["r", "2"], "+", 
             RowBox[{
              SuperscriptBox["\[Epsilon]a", "2"], 
              SuperscriptBox[
               RowBox[{"(", 
                FractionBox["J", "M"], ")"}], "2"]}]}], ")"}], 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "+", 
          RowBox[{
           FractionBox[
            RowBox[{"2", " ", "M", " ", "r"}], "\[CapitalSigma]"], 
           SuperscriptBox["\[Epsilon]a", "2"], 
           SuperscriptBox[
            RowBox[{"(", 
             FractionBox["J", "M"], ")"}], "2"], 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "4"]}]}], ")"}]}], "}"}]}],
      "}"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"gddPOLAR", "=", 
     RowBox[{"\[Epsilon]p", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "\[Omega]", " ", "t"}], "]"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"H0", "[", "r", "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"H1", "[", "r", "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
          "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"H1", "[", "r", "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"H2", "[", "r", "]"}], " ", 
           RowBox[{"Y", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
          "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           SuperscriptBox["r", "2"], 
           RowBox[{"K", "[", "r", "]"}], 
           RowBox[{"Y", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0"}], 
         "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", "0", ",", 
          RowBox[{
           SuperscriptBox["r", "2"], 
           RowBox[{"K", "[", "r", "]"}], 
           RowBox[{"Y", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
           SuperscriptBox[
            RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], "}"}]}], 
       "}"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"gddAXIAL", "=", 
     RowBox[{"\[Epsilon]p", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "I"}], " ", "\[Omega]", " ", "t"}], "]"}], 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"h0", "[", "r", "]"}], 
           RowBox[{"S\[Theta]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"h0", "[", "r", "]"}], 
           RowBox[{"S\[CurlyPhi]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0", ",", 
          RowBox[{
           RowBox[{"h1", "[", "r", "]"}], 
           RowBox[{"S\[Theta]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"h1", "[", "r", "]"}], 
           RowBox[{"S\[CurlyPhi]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"h0", "[", "r", "]"}], 
           RowBox[{"S\[Theta]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"h1", "[", "r", "]"}], 
           RowBox[{"S\[Theta]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
          "0"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{
           RowBox[{"h0", "[", "r", "]"}], 
           RowBox[{"S\[CurlyPhi]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", 
          RowBox[{
           RowBox[{"h1", "[", "r", "]"}], 
           RowBox[{"S\[CurlyPhi]", "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ",", "0", ",", 
          "0"}], "}"}]}], "}"}]}]}], ";"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "***)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ORDERa", "=", "2"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "this", " ", "is", " ", "the", " ", "order", " ", "of", " ", "the", " ", 
    "perturbative", " ", "scheme", " ", "in", " ", "the", " ", "angular", " ",
     "momentum"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ORDERp", "=", "1"}], ";"}], " ", 
  RowBox[{"(*", 
   RowBox[{
   "this", " ", "is", " ", "the", " ", "order", " ", "of", " ", "the", " ", 
    "perturbative", " ", "scheme", " ", "in", " ", "the", " ", "field", " ", 
    "perturbations"}], "*)"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{
  3.496820244298901*^9, {3.4968203558284407`*^9, 3.4968203581404247`*^9}, {
   3.49682248740961*^9, 3.496822507434391*^9}, {3.496822916648978*^9, 
   3.496822924245894*^9}, {3.4968253627796383`*^9, 3.496825365436624*^9}, 
   3.504365165228209*^9, 3.5043809459936323`*^9, {3.504438008491736*^9, 
   3.5044380168067007`*^9}, {3.504495748442292*^9, 3.5044957514036427`*^9}, {
   3.504496120769294*^9, 3.5044961214237957`*^9}, {3.5045400430935097`*^9, 
   3.504540043486771*^9}, 3.504540099117354*^9, {3.504855376546852*^9, 
   3.504855377019938*^9}, {3.5070126406487007`*^9, 3.5070126683387003`*^9}, {
   3.5070165389565005`*^9, 3.507016542543501*^9}, {3.5070192092245007`*^9, 
   3.5070192094035006`*^9}, {3.5070197713987007`*^9, 3.5070197715859003`*^9}, 
   3.5072287166493998`*^9, {3.5370790428078938`*^9, 3.537079043326592*^9}, {
   3.537082332873783*^9, 3.537082336116788*^9}, {3.537082380862068*^9, 
   3.537082398365637*^9}, {3.537083684886382*^9, 3.537083686680084*^9}, {
   3.537083807108232*^9, 3.537083809984517*^9}, {3.537084029485549*^9, 
   3.537084029592424*^9}, {3.537084228699411*^9, 3.537084229009631*^9}, {
   3.537093739462956*^9, 3.537093837223934*^9}, {3.537094060161274*^9, 
   3.537094250708188*^9}, {3.537094294240178*^9, 3.537094391948748*^9}, {
   3.537098735560296*^9, 3.537098742730391*^9}, 3.537098777194285*^9, 
   3.5370992500223923`*^9, {3.537100125866765*^9, 3.5371001690948153`*^9}, {
   3.537100225767215*^9, 3.537100259114603*^9}, {3.537100305753476*^9, 
   3.5371003081749353`*^9}, {3.537100491593274*^9, 3.5371004924902477`*^9}, {
   3.537158374354004*^9, 3.537158410503768*^9}, 3.537158797548081*^9, {
   3.537158899745922*^9, 3.537158932610425*^9}, {3.537159695644637*^9, 
   3.537159703152467*^9}, {3.537159958755862*^9, 3.5371599659978447`*^9}, {
   3.537160571391717*^9, 3.53716061470122*^9}, {3.5371607191431713`*^9, 
   3.537160723528596*^9}, {3.537160855851684*^9, 3.537160857974311*^9}, 
   3.5371608929671307`*^9, {3.537160936616355*^9, 3.537160951620933*^9}, {
   3.5371611515848303`*^9, 3.537161190246645*^9}, {3.537161265251857*^9, 
   3.537161266644121*^9}, {3.5371623243443117`*^9, 3.5371623330720263`*^9}, {
   3.53716364472329*^9, 3.537163666152609*^9}, 3.537165626663948*^9, 
   3.5371667811150513`*^9, 3.53716685907119*^9, {3.5371675934571466`*^9, 
   3.537167596308173*^9}, 3.5371676307084017`*^9, {3.538477915363757*^9, 
   3.538477978002437*^9}, {3.538478215699177*^9, 3.538478262124633*^9}, {
   3.538478293275176*^9, 3.538478395622587*^9}, {3.5387267262357492`*^9, 
   3.538726728116671*^9}, {3.538733367565587*^9, 3.538733368090104*^9}, 
   3.538888288897168*^9, 3.5389371326852503`*^9, 3.540563212618326*^9, 
   3.545123720477861*^9, {3.545124117565865*^9, 3.5451243369836807`*^9}, {
   3.570721271615847*^9, 3.570721271905953*^9}, {3.57072130628686*^9, 
   3.570721306741213*^9}, {3.570721732131874*^9, 3.5707217348057528`*^9}, {
   3.5707218355607357`*^9, 3.570721839067415*^9}, {3.570722753331513*^9, 
   3.570722792038842*^9}}],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"This", " ", "does", " ", 
    RowBox[{"nothing", " ", ":"}]}], ")"}], TraditionalForm]],
 FormatType->"TraditionalForm"]], "Text",
 CellChangeTimes->{{3.570722807980754*^9, 3.5707228508683853`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"BISERIES", "[", "Z_", "]"}], ":=", "Z"}], ";"}]], "Input",
 CellChangeTimes->{{3.5707228410453453`*^9, 3.570722842073864*^9}}],

Cell["\<\
Metric, inverse and determinant:\
\>", "Text",
 CellChangeTimes->{{3.570722868173148*^9, 3.5707228747375917`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"gdd", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{"gdd0", ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"guu", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Inverse", "[", "gdd", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DET", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"Det", "[", "gdd", "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"dim", "=", 
   RowBox[{"Length", "[", "gdd", "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"g", "[", 
       RowBox[{"i", ",", "j"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{
        RowBox[{"gdd", "[", 
         RowBox[{"[", "i", "]"}], "]"}], "[", 
        RowBox[{"[", "j", "]"}], "]"}], "]"}]}], ";"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "gdd", "]"}], "\[IndentingNewLine]", 
 RowBox[{"MatrixForm", "[", "guu", "]"}]}], "Input",
 CellChangeTimes->{{3.496822745111134*^9, 3.4968227573539257`*^9}, {
   3.5070135576051006`*^9, 3.5070135731427007`*^9}, 3.5370938075446243`*^9, 
   3.537095344094717*^9, {3.537098138756166*^9, 3.537098146563369*^9}, {
   3.537098271648501*^9, 3.5370982751763487`*^9}, {3.537098684015606*^9, 
   3.537098700926721*^9}, {3.537098757113214*^9, 3.537098786418333*^9}, {
   3.537159707508955*^9, 3.5371597153437366`*^9}, {3.5371599807500267`*^9, 
   3.5371599814632893`*^9}, {3.5371668606922827`*^9, 3.537166870885435*^9}, {
   3.570721845160015*^9, 3.570721845409676*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       RowBox[{"-", "1"}], "+", 
       FractionBox[
        RowBox[{"2", " ", "M"}], "r"], "-", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["J", "2"], " ", 
         SuperscriptBox["\[Epsilon]a", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], 
        RowBox[{"M", " ", 
         SuperscriptBox["r", "3"]}]]}], "0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "J", " ", "\[Epsilon]a", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "r"]}]},
     {"0", 
      RowBox[{
       FractionBox["r", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", "M"}], "+", "r"}]], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["J", "2"], " ", 
         SuperscriptBox["\[Epsilon]a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "r"}], "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], 
        RowBox[{
         SuperscriptBox["M", "2"], " ", "r", " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]]}], 
      "0", "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox["r", "2"], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["J", "2"], " ", 
         SuperscriptBox["\[Epsilon]a", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], 
        SuperscriptBox["M", "2"]]}], "0"},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "J", " ", "\[Epsilon]a", " ", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], "r"]}], "0", "0", 
      FractionBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "3"], "+", 
          FractionBox[
           RowBox[{
            SuperscriptBox["J", "2"], " ", 
            SuperscriptBox["\[Epsilon]a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"r", "+", 
              RowBox[{"2", " ", "M", " ", 
               SuperscriptBox[
                RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], 
           SuperscriptBox["M", "2"]]}], ")"}]}], "r"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBeJ339sZZ0a9crz5a4IZiP7x860ziHafXxEFov8EHowH
0SdEtLtAtFe0Ac8sIJ2XOXPFbCD9qeet7Rwg/egFizOIFsrsXQSi4x6+FpgL
pDM43iqC6MSgXSYgesO+IydAtPl249ovMa8cn6yb81c6FmiP2uqXU4H05kNy
GjOB9DGx2FmHgPQEzjXLQPSp+wnOh4F0ztlLHaeB9COhC+eeAOktnw4s/wOk
z9zuaxaMe+VYf2vFJCEgfeWkaqUzkL6w9XmNWOIrxyMH/i0E0ZNesppqA+lX
W+s3s6e8cpwxI3//ycxXjvvivJedAtIuM1N83gDpBxO/nPTIAtpv92r2dCBd
tMVM9xqQtv/XEv00+5Vj2V1blzmzXjmmKS2sBdEan1+2geju9yGsc4F0f43o
osK5rxx5JjQ/bALSAGUNxcg=
  "]],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox["r", 
        RowBox[{
         RowBox[{"2", " ", "M"}], "-", "r"}]], "+", 
       FractionBox[
        RowBox[{"2", " ", 
         SuperscriptBox["J", "2"], " ", 
         SuperscriptBox["\[Epsilon]a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"r", " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
           RowBox[{"2", " ", "M", " ", 
            SuperscriptBox[
             RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], 
        RowBox[{"M", " ", 
         SuperscriptBox["r", "2"], " ", 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]]}], 
      "0", "0", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "J", " ", "\[Epsilon]a"}], 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}]]}]},
     {"0", 
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"2", " ", "M"}], "r"], "+", 
       FractionBox[
        RowBox[{
         SuperscriptBox["J", "2"], " ", 
         SuperscriptBox["\[Epsilon]a", "2"], " ", 
         RowBox[{"(", 
          RowBox[{"r", "+", 
           RowBox[{
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
            SuperscriptBox[
             RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], 
        RowBox[{
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "3"]}]]}], "0", "0"},
     {"0", "0", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox["r", "2"]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["J", "2"], " ", 
         SuperscriptBox["\[Epsilon]a", "2"], " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], 
        RowBox[{
         SuperscriptBox["M", "2"], " ", 
         SuperscriptBox["r", "4"]}]]}], "0"},
     {
      RowBox[{"-", 
       FractionBox[
        RowBox[{"2", " ", "J", " ", "\[Epsilon]a"}], 
        RowBox[{
         SuperscriptBox["r", "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}]]}], "0", "0", 
      
      FractionBox[
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["r", "2"], "-", 
          FractionBox[
           RowBox[{
            SuperscriptBox["J", "2"], " ", 
            SuperscriptBox["\[Epsilon]a", "2"], " ", 
            RowBox[{"(", 
             RowBox[{"M", "-", "r", "+", 
              RowBox[{"M", " ", 
               RowBox[{"Cos", "[", 
                RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}]}], 
           RowBox[{
            SuperscriptBox["M", "2"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"2", " ", "M"}], "-", "r"}], ")"}]}]]}], ")"}], " ", 
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], 
       SuperscriptBox["r", "4"]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmVkYGDQBeJ339sZZ0a9crz5a4IZiP7x860ziHafXxEFov8EHowH
0SdEtLtAtFe0Ac8sIJ2XOXPFbCD9qeet7Rwg/egFizOIFsrsXQSi4x6+FpgL
pDM43iqC6MSgXSYgesO+IydAtPl249ovMa8cn6yb81c6FmiP2uqXU4H05kNy
GjOB9DGx2FmHgPQEzjXLQPSp+wnOh4F0ztlLHaeB9COhC+eeAOktnw4s/wOk
z9zuaxaMe+VYf2vFJCEgfeWkaqUzkL6w9XmNWOIrxyMH/i0E0ZNesppqA+lX
W+s3s6e8cpwxI3//ycxXjvvivJedAtIuM1N83gDpBxO/nPTIAtpv92r2dCBd
tMVM9xqQtv/XEv00+5Vj2V1blzmzXjmmKS2sBdEan1+2geju9yGsc4F0f43o
osK5rxz1njY/bALSAGhwxj8=
  "]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Klein-Gordon equation:", "Section"]], "Subtitle",
 CellChangeTimes->{{3.4748662984784307`*^9, 3.474866318276967*^9}, {
  3.49682537622365*^9, 3.496825382669928*^9}, {3.516876275160224*^9, 
  3.516876279587028*^9}, {3.5355440086694717`*^9, 3.535544016131024*^9}, {
  3.570721366769459*^9, 3.570721375724918*^9}, {3.5707214260030746`*^9, 
  3.5707214286436462`*^9}, {3.570721486927219*^9, 3.570721487845373*^9}, {
  3.570721861181693*^9, 3.570721865943096*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"\[Phi]", ",", "\[CapitalPhi]1", ",", "\[Phi]p"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Phi]", "=", 
    RowBox[{"\[Epsilon]p", " ", 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], 
     RowBox[{"(", 
      RowBox[{"\[Phi]p", "[", 
       RowBox[{"r", ",", "t"}], "]"}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LHS", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         FractionBox["1", 
          SqrtBox[
           RowBox[{"-", "DET"}]]], 
         RowBox[{"Sum", "[", 
          RowBox[{
           RowBox[{"D", "[", 
            RowBox[{
             RowBox[{
              SqrtBox[
               RowBox[{"-", "DET"}]], 
              RowBox[{"D", "[", 
               RowBox[{"\[Phi]", ",", 
                RowBox[{"x", "[", 
                 RowBox[{"[", "i", "]"}], "]"}]}], "]"}], 
              RowBox[{
               RowBox[{"guu", "[", 
                RowBox[{"[", "i", "]"}], "]"}], "[", 
               RowBox[{"[", "j", "]"}], "]"}]}], ",", 
             RowBox[{"x", "[", 
              RowBox[{"[", "j", "]"}], "]"}]}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"i", ",", "1", ",", "dim"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"j", ",", "1", ",", "dim"}], "}"}]}], "]"}]}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"RHS", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"BISERIES", "[", 
     RowBox[{"Normal", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{
         SuperscriptBox["\[Mu]", "2"], " ", "\[Phi]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]p", ",", "0", ",", "ORDERp"}], "}"}]}], "]"}], 
      "]"}], "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"EQDIL", "=", 
  RowBox[{"Simplify", "[", " ", 
   RowBox[{"(", 
    RowBox[{"LHS", "-", "RHS"}], ")"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.494225822714517*^9, 3.494225935651701*^9}, {
   3.494243736231841*^9, 3.4942437433275423`*^9}, {3.494344012142809*^9, 
   3.494344022967853*^9}, 3.494587505070442*^9, {3.494863435052575*^9, 
   3.4948634359432697`*^9}, {3.49682046055167*^9, 3.4968204993881083`*^9}, {
   3.496821062920734*^9, 3.49682106467972*^9}, {3.496826487559401*^9, 
   3.496826497085766*^9}, {3.496826806176692*^9, 3.49682685664093*^9}, 
   3.4969002716964293`*^9, {3.496900510680613*^9, 3.496900523596499*^9}, {
   3.499429487924271*^9, 3.499429527785096*^9}, {3.499430111837267*^9, 
   3.499430122180519*^9}, {3.499430274903297*^9, 3.499430282846136*^9}, {
   3.504422247464003*^9, 3.504422247572927*^9}, {3.5044223102555227`*^9, 
   3.5044223136485167`*^9}, {3.504422614798112*^9, 3.504422640337072*^9}, {
   3.504423326060687*^9, 3.504423388816689*^9}, {3.504423450598926*^9, 
   3.504423468146142*^9}, 3.504423525421028*^9, {3.504423611335539*^9, 
   3.504423616616745*^9}, {3.50442822414247*^9, 3.504428256492443*^9}, {
   3.504428658875153*^9, 3.504428659513832*^9}, {3.5070160480917006`*^9, 
   3.507016080711301*^9}, {3.507016234230901*^9, 3.5070162366489005`*^9}, {
   3.5168771128603287`*^9, 3.516877179312602*^9}, {3.516877213347224*^9, 
   3.5168772626777897`*^9}, {3.516877308354082*^9, 3.516877391526739*^9}, {
   3.522752329886785*^9, 3.522752341500141*^9}, {3.535545022567733*^9, 
   3.535545022914996*^9}, {3.535545059441247*^9, 3.535545059450307*^9}, {
   3.537079389352181*^9, 3.537079389479549*^9}, {3.5370794235038633`*^9, 
   3.537079438156742*^9}, {3.537079525138042*^9, 3.537079525212371*^9}, {
   3.537081815890856*^9, 3.537081816853009*^9}, {3.537084208404068*^9, 
   3.537084208824049*^9}, {3.5370938085780478`*^9, 3.5370938086021833`*^9}, {
   3.53709534687464*^9, 3.537095347212886*^9}, {3.537098704623885*^9, 
   3.5370987049623833`*^9}, {3.5371630742073193`*^9, 3.537163089418721*^9}, 
   3.538478975270626*^9, {3.538818282098282*^9, 3.538818282726766*^9}, 
   3.5389375576593513`*^9, 3.54512447899839*^9, {3.570721435643417*^9, 
   3.570721481885153*^9}, {3.570722982087421*^9, 3.570722982209765*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "\[Epsilon]p"}], " ", 
   SuperscriptBox["\[Mu]", "2"], " ", 
   RowBox[{"Y", "[", 
    RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
   RowBox[{"\[Phi]p", "[", 
    RowBox[{"r", ",", "t"}], "]"}]}], "+", 
  RowBox[{
   FractionBox["1", 
    RowBox[{
     SuperscriptBox["M", "2"], " ", 
     SuperscriptBox["r", "4"], " ", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}]], 
   RowBox[{"\[Epsilon]p", " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"4", " ", "J", " ", 
       SuperscriptBox["M", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
       SuperscriptBox["r", "2"], " ", "\[Epsilon]a", " ", 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
       RowBox[{
        SuperscriptBox["\[Phi]p", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"0", ",", "1"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"r", ",", "t"}], "]"}]}], "+", 
      RowBox[{
       FractionBox["1", "8"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
       SuperscriptBox[
        RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
       RowBox[{"\[Phi]p", "[", 
        RowBox[{"r", ",", "t"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"8", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["M", "3"], " ", 
             SuperscriptBox["r", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["M", "2"], " ", 
             SuperscriptBox["r", "3"]}], "-", 
            RowBox[{
             SuperscriptBox["J", "2"], " ", "M", " ", 
             SuperscriptBox["\[Epsilon]a", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["J", "2"], " ", "r", " ", 
             SuperscriptBox["\[Epsilon]a", "2"]}], "-", 
            RowBox[{
             SuperscriptBox["J", "2"], " ", "M", " ", 
             SuperscriptBox["\[Epsilon]a", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
         RowBox[{"4", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", 
             SuperscriptBox["M", "2"], " ", 
             SuperscriptBox["r", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["J", "2"], " ", 
             SuperscriptBox["\[Epsilon]a", "2"]}], "+", 
            RowBox[{
             SuperscriptBox["J", "2"], " ", 
             SuperscriptBox["\[Epsilon]a", "2"], " ", 
             RowBox[{"Cos", "[", 
              RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}], " ", 
          RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
            RowBox[{
             RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
        ")"}]}], "+", 
      RowBox[{
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"M", " ", 
          SuperscriptBox["r", "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", 
             SuperscriptBox["J", "2"], " ", "r", " ", 
             SuperscriptBox["\[Epsilon]a", "2"], " ", 
             SuperscriptBox[
              RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}], "+", 
            RowBox[{"M", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                SuperscriptBox["r", "3"]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["J", "2"], " ", 
                SuperscriptBox["\[Epsilon]a", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{
           SuperscriptBox["\[Phi]p", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"r", ",", "t"}], "]"}]}], "-", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{"M", "-", "r"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                SuperscriptBox["M", "2"], " ", 
                SuperscriptBox["r", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["J", "2"], " ", 
                SuperscriptBox["\[Epsilon]a", "2"]}], "-", 
               RowBox[{
                SuperscriptBox["J", "2"], " ", 
                SuperscriptBox["\[Epsilon]a", "2"], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["\[Phi]p", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"r", ",", "t"}], "]"}]}], "-", 
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "2"}], " ", 
                   SuperscriptBox["M", "3"], " ", "r"}], "+", 
                  RowBox[{
                   SuperscriptBox["M", "2"], " ", 
                   SuperscriptBox["r", "2"]}], "+", 
                  RowBox[{
                   SuperscriptBox["J", "2"], " ", 
                   SuperscriptBox["\[Epsilon]a", "2"]}]}], ")"}]}], "+", 
               RowBox[{
                SuperscriptBox["J", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                SuperscriptBox["\[Epsilon]a", "2"], " ", 
                SuperscriptBox[
                 RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
             
             RowBox[{
              SuperscriptBox["\[Phi]p", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"r", ",", "t"}], "]"}]}]}], ")"}]}]}], ")"}]}]}], 
     ")"}]}]}]}]], "Output",
 CellChangeTimes->{
  3.540605386006896*^9, 3.545124444910136*^9, 3.5451244826712627`*^9, 
   3.54512622479821*^9, 3.545195144957053*^9, 3.545384554165978*^9, 
   3.5455460289167023`*^9, 3.545674117932291*^9, 3.570721474238968*^9, 
   3.570721877067931*^9, {3.57072297810203*^9, 3.570722993687387*^9}, 
   3.572206892875517*^9, 3.572242219267179*^9}]
}, Open  ]],

Cell["\<\
If we wish, we can save the result:\
\>", "Text",
 CellChangeTimes->{{3.570722953606166*^9, 3.5707229590645103`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<eqdil.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"EQDIL", ",", "ORDERa"}], "}"}]}], "]"}], ";"}]}], "Input",
 CellChangeTimes->{{3.57072196350493*^9, 3.570721975697083*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rest:", "Title",
 CellChangeTimes->{{3.5384789822991123`*^9, 3.538478988277007*^9}}],

Cell[CellGroupData[{

Cell["\<\
Definitions [we redefine the scalar field]\
\>", "Subsubsection",
 CellChangeTimes->{{3.545625272562451*^9, 3.545625281338798*^9}, {
  3.570723012601918*^9, 3.570723023069275*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{"f", ",", "\[CapitalDelta]"}], "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"<<", "eqdil.mx"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"a", "=", 
   RowBox[{"(", 
    RowBox[{"\[Epsilon]a", 
     FractionBox["J", "M"]}], ")"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalDelta]", "[", "r_", "]"}], ":=", 
   RowBox[{
    SuperscriptBox["r", "2"], "+", 
    SuperscriptBox["a", "2"], "-", 
    RowBox[{"2", "M", " ", "r"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"f", "[", "r_", "]"}], ":=", 
   FractionBox[
    RowBox[{"\[CapitalDelta]", "[", "r", "]"}], 
    RowBox[{
     SuperscriptBox["r", "2"], "+", 
     SuperscriptBox["a", "2"]}]]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"F", "[", "r_", "]"}], ":=", 
   RowBox[{"1", "-", 
    RowBox[{"2", 
     RowBox[{"M", "/", "r"}]}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SJ", "[", "X_", "]"}], ":=", 
    RowBox[{"Normal", "[", 
     RowBox[{"Series", "[", 
      RowBox[{"X", ",", 
       RowBox[{"{", 
        RowBox[{"\[Epsilon]a", ",", "0", ",", "ORDERa"}], "}"}]}], "]"}], 
     "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "**)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", "**)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Phi]p", "[", 
     RowBox[{"r_", ",", "t_"}], "]"}], ":=", 
    RowBox[{
     FractionBox[
      RowBox[{
       RowBox[{"\[Psi]", "[", "l", "]"}], "[", "r", "]"}], 
      SqrtBox[
       RowBox[{
        SuperscriptBox["r", "2"], "+", 
        SuperscriptBox["a", "2"]}]]], " ", 
     RowBox[{"Exp", "[", 
      RowBox[{
       RowBox[{"-", "I"}], " ", "\[Omega]", " ", "t"}], "]"}]}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "**)"}]}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.545547793276966*^9, 3.545547793391523*^9}, 
   3.54554782807479*^9, {3.5455478907963457`*^9, 3.54554789093683*^9}, {
   3.545547941275316*^9, 3.545547942386566*^9}, 3.545548293480628*^9, {
   3.54554839949164*^9, 3.545548465621687*^9}, {3.5455485554319487`*^9, 
   3.54554857301972*^9}, {3.545549198235793*^9, 3.545549277176585*^9}, 
   3.545568913217679*^9, {3.545576275026018*^9, 3.5455762787849913`*^9}, {
   3.545659667229185*^9, 3.545659680032628*^9}, {3.545659777127331*^9, 
   3.5456597815983477`*^9}, {3.545712173231328*^9, 3.545712188964107*^9}, {
   3.545712225194872*^9, 3.545712240814207*^9}, {3.545909638860909*^9, 
   3.545909664275133*^9}, 3.545910634216015*^9, {3.546255111707265*^9, 
   3.546255115979402*^9}, {3.570721903363969*^9, 3.5707219560277567`*^9}, {
   3.5707219905823517`*^9, 3.570722001294595*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Angular definition: (this implements various properties of the spherical \
harmonics)\
\>", "Subsubsection",
 CellChangeTimes->{{3.537169436071678*^9, 3.537169438199121*^9}, 
   3.53847897527479*^9, {3.570722006994546*^9, 3.5707220079781647`*^9}, {
   3.570723032136051*^9, 3.570723052978311*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$Assumptions", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"r", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[GreaterEqual]", "0"}], ",", 
     RowBox[{"\[Theta]", "\[LessEqual]", "\[Pi]"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S\[Theta]", "[", 
    RowBox[{"\[Theta]_", ",", "\[CurlyPhi]_"}], "]"}], ":=", 
   RowBox[{
    FractionBox[
     RowBox[{"-", "1"}], 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], ",", "\[CurlyPhi]"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"S\[CurlyPhi]", "[", 
    RowBox[{"\[Theta]_", ",", "\[CurlyPhi]_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"Sin", "[", "\[Theta]", "]"}], 
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], ",", "\[Theta]"}], 
     "]"}]}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"X", "[", "\[Theta]_", "]"}], ":=", 
   SuperscriptBox[
    RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleANG", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], 
        RowBox[{"(", 
         RowBox[{"l", "+", "1"}], ")"}], 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        FractionBox["1", 
         SuperscriptBox[
          RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", "l", "+", 
          SuperscriptBox["l", "2"]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "0"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{"2", " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ")"}]}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"4", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l", "+", 
          SuperscriptBox["l", "2"], "-", 
          RowBox[{"3", " ", 
           SuperscriptBox[
            RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
        RowBox[{"Y", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{"7", "+", "l", "+", 
             SuperscriptBox["l", "2"], "-", 
             RowBox[{"11", " ", 
              SuperscriptBox[
               RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"0", ",", "2"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{
              RowBox[{"(", 
               RowBox[{"1", "+", 
                RowBox[{"2", " ", "l", " ", 
                 RowBox[{"(", 
                  RowBox[{"1", "+", "l"}], ")"}]}]}], ")"}], " ", 
              RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
             RowBox[{"6", " ", 
              RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
              RowBox[{"Csc", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
          RowBox[{
           RowBox[{"Csc", "[", "\[Theta]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"5", " ", 
              RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
              RowBox[{
               SuperscriptBox["Y", 
                TagBox[
                 RowBox[{"(", 
                  RowBox[{"1", ",", "2"}], ")"}],
                 Derivative],
                MultilineFunction->None], "[", 
               RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"2", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ")"}]}]}], 
         ")"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "l"}], " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "4"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleANG2", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        FractionBox["1", "2"], " ", 
        RowBox[{"XX", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"W", "[", 
             RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "+", 
            RowBox[{"l", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], 
         "+", 
         RowBox[{"2", " ", 
          RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"W", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "-", 
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", 
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"W", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
         RowBox[{"l", " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l"}], ")"}], " ", 
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"Y", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "2"}], "+", "l", "+", 
            SuperscriptBox["l", "2"], "+", 
            SuperscriptBox[
             RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], ")"}], " ", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "0"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"1", ",", "2"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
     ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"4", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", 
           RowBox[{"(", 
            RowBox[{"7", "+", 
             RowBox[{"2", " ", "l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}]}], "-", 
             RowBox[{"11", " ", 
              SuperscriptBox[
               RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}]}], " ", 
          
          RowBox[{"W", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "4"], " ", 
          RowBox[{
           SuperscriptBox["Y", 
            TagBox[
             RowBox[{"(", 
              RowBox[{"0", ",", "4"}], ")"}],
             Derivative],
            MultilineFunction->None], "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
         RowBox[{
          RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"5", " ", "l", " ", 
             RowBox[{"(", 
              RowBox[{"1", "+", "l"}], ")"}], " ", 
             RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
             RowBox[{"Y", "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
            RowBox[{"2", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "6"}], "+", 
               RowBox[{"5", " ", 
                SuperscriptBox[
                 RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
             
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "0"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
            RowBox[{"12", " ", 
             SuperscriptBox[
              RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "2"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
        ")"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         FractionBox["1", "2"]}], " ", 
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"XX", "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"l", "+", 
          SuperscriptBox["l", "2"], "+", 
          SuperscriptBox[
           RowBox[{"Cot", "[", "\[Theta]", "]"}], "2"]}], ")"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "1"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
       RowBox[{
        SuperscriptBox[
         RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "3"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"2", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox[
          RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"0", ",", "4"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
       RowBox[{
        FractionBox["1", "2"], " ", "l", " ", 
        RowBox[{"(", 
         RowBox[{"1", "+", "l"}], ")"}], " ", 
        RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"W", "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "+", 
             RowBox[{"l", " ", 
              RowBox[{"(", 
               RowBox[{"1", "+", "l"}], ")"}], " ", 
              RowBox[{"Y", "[", 
               RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], 
          "+", 
          RowBox[{"2", " ", 
           RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
           RowBox[{
            SuperscriptBox["Y", 
             TagBox[
              RowBox[{"(", 
               RowBox[{"1", ",", "0"}], ")"}],
              Derivative],
             MultilineFunction->None], "[", 
            RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], "-", 
       RowBox[{
        RowBox[{"Cot", "[", "\[Theta]", "]"}], " ", 
        RowBox[{
         SuperscriptBox["Y", 
          TagBox[
           RowBox[{"(", 
            RowBox[{"1", ",", "2"}], ")"}],
           Derivative],
          MultilineFunction->None], "[", 
         RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"3", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       FractionBox["1", "4"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "2"}], " ", 
          RowBox[{"(", 
           RowBox[{"1", "+", "l", "+", 
            SuperscriptBox["l", "2"], "-", 
            RowBox[{"2", " ", 
             SuperscriptBox[
              RowBox[{"Csc", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], " ", 
          RowBox[{"XX", "[", 
           RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"Csc", "[", "\[Theta]", "]"}], "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"7", " ", 
                RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "+", 
               RowBox[{"Cos", "[", 
                RowBox[{"3", " ", "\[Theta]"}], "]"}]}], ")"}], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "1"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
            RowBox[{"12", " ", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"0", ",", "3"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "-", 
            RowBox[{"4", " ", 
             RowBox[{"Sin", "[", "\[Theta]", "]"}], " ", 
             RowBox[{
              SuperscriptBox["Y", 
               TagBox[
                RowBox[{"(", 
                 RowBox[{"1", ",", "3"}], ")"}],
                Derivative],
               MultilineFunction->None], "[", 
              RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}]}], 
        ")"}]}]}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.537248251134644*^9, 3.537248268481345*^9}, {
   3.5372500792999687`*^9, 3.537250088360345*^9}, {3.537253909457386*^9, 
   3.537253926144947*^9}, {3.5372539814636497`*^9, 3.5372539881597357`*^9}, {
   3.538399431779244*^9, 3.538399432036621*^9}, 3.538478975291098*^9, 
   3.538485294580593*^9, {3.538726846429902*^9, 3.538726850118156*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"ruleNO\[CurlyPhi]", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{"I", " ", "m", " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["m", "2"]}], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "1"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{"I", " ", "m", " ", 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "2"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["m", "2"]}], 
       RowBox[{
        SuperscriptBox["Y", 
         TagBox[
          RowBox[{"(", 
           RowBox[{"1", ",", "0"}], ")"}],
          Derivative],
         MultilineFunction->None], "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ",", 
     RowBox[{
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"0", ",", "3"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], "\[Rule]", 
      RowBox[{
       RowBox[{"-", "I"}], " ", 
       SuperscriptBox["m", "3"], " ", 
       RowBox[{"Y", "[", 
        RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ruleT", "=", 
   RowBox[{"Union", "[", 
    RowBox[{"ruleANG", ",", "ruleNO\[CurlyPhi]", ",", 
     RowBox[{"{", 
      RowBox[{
       SqrtBox[
        SuperscriptBox[
         RowBox[{"Sin", "[", "\[Theta]", "]"}], "2"]], "\[Rule]", 
       RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.538485298681395*^9, 3.5384853912777452`*^9}, {
   3.5384854349742107`*^9, 3.538485449974841*^9}, {3.5384866012135572`*^9, 
   3.538486628396125*^9}, {3.538723494972435*^9, 3.538723502475541*^9}, {
   3.538726898558275*^9, 3.538726905205079*^9}, 3.538729084576704*^9, 
   3.538729140888191*^9, {3.53873078262709*^9, 3.538730782787993*^9}, {
   3.5387311829046783`*^9, 3.538731183316236*^9}, {3.538733897471884*^9, 
   3.5387339047183523`*^9}, {3.5388889502067127`*^9, 3.538888950346525*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Separation of the angular part:\
\>", "Subsubsection",
 CellChangeTimes->{{3.5405633451046143`*^9, 3.540563348518177*^9}, {
  3.545557685185483*^9, 3.545557689503373*^9}, {3.570722240413619*^9, 
  3.570722243527638*^9}, {3.5707230625973597`*^9, 3.5707230653245163`*^9}}],

Cell["\<\
First, we apply the rules above the KG equation:\
\>", "Text",
 CellChangeTimes->{{3.570723068623448*^9, 3.5707230794261923`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"EQ", "=", 
  RowBox[{"Simplify", "[", 
   RowBox[{"SJ", "[", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", "1", ")"}], 
       RowBox[{"-", "1"}]], "EQDIL"}], "//.", "ruleT"}], "]"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{
  FractionBox["1", 
   RowBox[{"2", " ", 
    SuperscriptBox["r", "6"]}]], 
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], " ", 
   "\[Epsilon]p", " ", 
   RowBox[{"Y", "[", 
    RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"-", 
      FractionBox[
       RowBox[{"8", " ", "J", " ", "m", " ", 
        SuperscriptBox["r", "3"], " ", "\[Epsilon]a", " ", "\[Omega]", " ", 
        RowBox[{
         RowBox[{"\[Psi]", "[", "l", "]"}], "[", "r", "]"}]}], 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "M"}], "+", "r"}]]}], "+", 
     FractionBox[
      RowBox[{"2", " ", 
       SuperscriptBox["r", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"4", " ", 
             SuperscriptBox["M", "2"]}], "+", 
            RowBox[{"2", " ", "M", " ", "r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1"}], "+", "l", "+", 
               SuperscriptBox["l", "2"], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                SuperscriptBox["\[Mu]", "2"]}]}], ")"}]}], "-", 
            RowBox[{
             SuperscriptBox["r", "2"], " ", 
             RowBox[{"(", 
              RowBox[{"l", "+", 
               SuperscriptBox["l", "2"], "+", 
               RowBox[{
                SuperscriptBox["r", "2"], " ", 
                RowBox[{"(", 
                 RowBox[{
                  SuperscriptBox["\[Mu]", "2"], "-", 
                  SuperscriptBox["\[Omega]", "2"]}], ")"}]}]}], ")"}]}]}], 
           ")"}], " ", 
          RowBox[{
           RowBox[{"\[Psi]", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "2"}], " ", "M", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Psi]", "[", "l", "]"}], "\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}], "+", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
             RowBox[{
              SuperscriptBox[
               RowBox[{"\[Psi]", "[", "l", "]"}], "\[Prime]\[Prime]",
               MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
        ")"}]}], 
      RowBox[{
       RowBox[{
        RowBox[{"-", "2"}], " ", "M"}], "+", "r"}]], "+", 
     RowBox[{
      RowBox[{"1", "/", 
       SuperscriptBox["M", "2"]}], 
      RowBox[{
       SuperscriptBox["J", "2"], " ", 
       SuperscriptBox["\[Epsilon]a", "2"], " ", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          SuperscriptBox["r", "3"], " ", 
          SuperscriptBox["\[Mu]", "2"], " ", 
          RowBox[{
           RowBox[{"\[Psi]", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
         RowBox[{
          RowBox[{"1", "/", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"]}], 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"r", " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   SuperscriptBox["m", "2"], " ", "r"}], "+", 
                  RowBox[{"l", " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}], "+", 
                  
                  RowBox[{
                   SuperscriptBox["l", "2"], " ", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}]}]}], 
                 ")"}]}], "-", 
               RowBox[{"l", " ", 
                RowBox[{"(", 
                 RowBox[{"1", "+", "l"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"\[Psi]", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                RowBox[{"-", "80"}], " ", 
                SuperscriptBox["M", "3"]}], "-", 
               RowBox[{"28", " ", "M", " ", 
                SuperscriptBox["r", "2"]}], "+", 
               RowBox[{
                SuperscriptBox["r", "3"], " ", 
                RowBox[{"(", 
                 RowBox[{"2", "+", 
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "+", 
               RowBox[{"4", " ", 
                SuperscriptBox["M", "2"], " ", "r", " ", 
                RowBox[{"(", 
                 RowBox[{"22", "+", 
                  RowBox[{
                   SuperscriptBox["r", "2"], " ", 
                   SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}], "-", 
               RowBox[{"2", " ", "M", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{"2", " ", "M"}], "-", "r", "+", 
                  RowBox[{
                   SuperscriptBox["r", "3"], " ", 
                   SuperscriptBox["\[Omega]", "2"]}]}], ")"}], " ", 
                RowBox[{"Cos", "[", 
                 RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}], " ", 
             RowBox[{
              RowBox[{"\[Psi]", "[", "l", "]"}], "[", "r", "]"}]}], "-", 
            RowBox[{"r", " ", 
             SuperscriptBox[
              RowBox[{"(", 
               RowBox[{
                RowBox[{
                 RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], "2"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"2", " ", "M", " ", 
                RowBox[{"(", 
                 RowBox[{"6", "+", 
                  RowBox[{"Cos", "[", 
                   RowBox[{"2", " ", "\[Theta]"}], "]"}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Psi]", "[", "l", "]"}], "\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}], "+", 
               RowBox[{"r", " ", 
                RowBox[{"(", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"-", "4"}], " ", "M"}], "+", 
                  RowBox[{
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"-", "2"}], " ", "M"}], "+", "r"}], ")"}], " ", 
                   RowBox[{"Cos", "[", 
                    RowBox[{"2", " ", "\[Theta]"}], "]"}]}]}], ")"}], " ", 
                RowBox[{
                 SuperscriptBox[
                  RowBox[{"\[Psi]", "[", "l", "]"}], "\[Prime]\[Prime]",
                  MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{
  3.5707223653903303`*^9, 3.570723082919636*^9, 3.572206987067545*^9, {
   3.572242282582238*^9, 3.572242290548335*^9}}]
}, Open  ]],

Cell["\<\
Then, we extract the coefficients of the various spherical harmonics\
\>", "Text",
 CellChangeTimes->{{3.570723092698621*^9, 3.570723110949401*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"cY", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{"Y", "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cYc2\[Theta]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY", ",", 
      RowBox[{"Cos", "[", 
       RowBox[{"2", "\[Theta]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cYc", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"cY0", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"cY", "-", 
      RowBox[{"cYc", " ", 
       RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "-", 
      RowBox[{"cYc2\[Theta]", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{"2", "\[Theta]"}], "]"}]}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]", 
  RowBox[{"(*", "**)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"EQ", ",", 
      RowBox[{
       SuperscriptBox["Y", 
        TagBox[
         RowBox[{"(", 
          RowBox[{"1", ",", "0"}], ")"}],
         Derivative],
        MultilineFunction->None], "[", 
       RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]s\[Theta]", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]", ",", 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]s\[Theta]c\[Theta]", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"Coefficient", "[", 
     RowBox[{"cY\[Theta]s\[Theta]", ",", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"cY\[Theta]s\[Theta]0", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"cY\[Theta]s\[Theta]", "-", 
     RowBox[{"cY\[Theta]s\[Theta]c\[Theta]", " ", 
      RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], "]"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5455513769076767`*^9, 3.545551446678381*^9}, {
  3.545555088690633*^9, 3.5455550952886047`*^9}, {3.545555783685521*^9, 
  3.5455558966380987`*^9}, {3.5455560553680143`*^9, 3.545556210936975*^9}, {
  3.5455565889901457`*^9, 3.54555661602353*^9}, {3.5455566783312187`*^9, 
  3.54555670738684*^9}, {3.545556766986858*^9, 3.545556778132945*^9}, {
  3.545557826303364*^9, 3.5455578289064827`*^9}, {3.545557891962167*^9, 
  3.545557959348864*^9}, {3.545557989820939*^9, 3.545558015112998*^9}, {
  3.545558045663436*^9, 3.545558127369259*^9}, {3.545558164267748*^9, 
  3.54555816646655*^9}, {3.54555826517752*^9, 3.54555827048177*^9}, {
  3.545712779363522*^9, 3.545712793150531*^9}, {3.545910662319254*^9, 
  3.5459106643058443`*^9}}],

Cell["\<\
CHECK: the equation is correctly expanded in the desired form and all \
coefficients are purely radial functions:\
\>", "Text",
 CellChangeTimes->{{3.5707231201065474`*^9, 3.570723156497693*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "***)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Print", "[", "\"\<Checks:\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"CHECK", "=", 
    RowBox[{"Simplify", "[", 
     RowBox[{"EQ", "-", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"(", 
          RowBox[{"cY0", "-", "cYc2\[Theta]"}], ")"}], " ", 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
        RowBox[{"cYc", " ", 
         RowBox[{"Cos", "[", "\[Theta]", "]"}], 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", 
        RowBox[{"2", "cYc2\[Theta]", " ", 
         SuperscriptBox[
          RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"], 
         RowBox[{"Y", "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], "+", " ", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"cY\[Theta]s\[Theta]0", " ", 
            RowBox[{"Sin", "[", "\[Theta]", "]"}]}], "+", 
           RowBox[{"cY\[Theta]s\[Theta]c\[Theta]", " ", 
            RowBox[{"Sin", "[", "\[Theta]", "]"}], 
            RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}], " ", 
         RowBox[{
          SuperscriptBox["Y", 
           TagBox[
            RowBox[{"(", 
             RowBox[{"1", ",", "0"}], ")"}],
            Derivative],
           MultilineFunction->None], "[", 
          RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}]}], ")"}]}], 
     "]"}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"vect", "=", 
     RowBox[{"{", 
      RowBox[{
      "cY0", ",", "cYc", ",", "cYc2\[Theta]", ",", "cY\[Theta]s\[Theta]0", 
       ",", "cY\[Theta]s\[Theta]c\[Theta]"}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"vect", ",", "\[Theta]"}], "]"}], "\[Equal]", 
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "vect", "]"}]}], "}"}]}], "]"}]}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{"vect", ",", "\[CurlyPhi]"}], "]"}], "\[Equal]", 
    RowBox[{"Table", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"i", ",", "1", ",", 
        RowBox[{"Length", "[", "vect", "]"}]}], "}"}]}], "]"}]}]}]}]], "Input",\

 CellChangeTimes->{{3.545558196576168*^9, 3.545558250915618*^9}, {
  3.545569105256179*^9, 3.545569118934325*^9}, {3.5722070510347548`*^9, 
  3.57220706430378*^9}}],

Cell[BoxData["\<\"Checks:\"\>"], "Print",
 CellChangeTimes->{
  3.54608110719281*^9, 3.546085606722196*^9, 3.547118198076069*^9, 
   3.5475213629257793`*^9, 3.547532560960803*^9, 3.5707223686804867`*^9, 
   3.570723159459474*^9, {3.572207046162024*^9, 3.572207065034081*^9}, 
   3.572242315029294*^9}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.546081107253211*^9, 3.5460856067827787`*^9, 3.547118198078927*^9, 
   3.5475213629817457`*^9, 3.547532561021982*^9, 3.5707223686982317`*^9, 
   3.570723159476995*^9, {3.572207046197319*^9, 3.5722070650535994`*^9}, 
   3.5722423150691032`*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.546081107253211*^9, 3.5460856067827787`*^9, 3.547118198078927*^9, 
   3.5475213629817457`*^9, 3.547532561021982*^9, 3.5707223686982317`*^9, 
   3.570723159476995*^9, {3.572207046197319*^9, 3.5722070650535994`*^9}, 
   3.572242315069976*^9}],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.546081107253211*^9, 3.5460856067827787`*^9, 3.547118198078927*^9, 
   3.5475213629817457`*^9, 3.547532561021982*^9, 3.5707223686982317`*^9, 
   3.570723159476995*^9, {3.572207046197319*^9, 3.5722070650535994`*^9}, 
   3.572242315072266*^9}]
}, Open  ]],

Cell["\<\
These are the coefficients in the notation used in the papers:\
\>", "Text",
 CellChangeTimes->{{3.570723164422974*^9, 3.570723175804481*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"AD", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{"cY0", "-", "cYc2\[Theta]"}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AtD", "=", "cYc"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BD", "=", "cY\[Theta]s\[Theta]0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"DD", "=", 
   RowBox[{"2", "cYc2\[Theta]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"BtD", "=", "cY\[Theta]s\[Theta]c\[Theta]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"{", 
  RowBox[{"AtD", ",", "BtD", ",", "BD"}], "}"}]}], "Input",
 CellChangeTimes->{{3.5455565102712793`*^9, 3.545556551136353*^9}, {
  3.545558278819783*^9, 3.545558307284775*^9}, {3.5455583781339827`*^9, 
  3.54555838490965*^9}, {3.545559282443378*^9, 3.545559282981791*^9}, {
  3.546081214179563*^9, 3.5460812563674707`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{{3.546081231136952*^9, 3.546081256788251*^9}, 
   3.5460856083006983`*^9, 3.547118200948556*^9, 3.547521364031794*^9, 
   3.5475325622604*^9, 3.570722370105253*^9, 3.5707231779197073`*^9, 
   3.5722070784644413`*^9, 3.572242355717657*^9}]
}, Open  ]],

Cell["\<\
Another check, just to make sure that we are dealing with the same original \
equation:\
\>", "Text",
 CellChangeTimes->{{3.5707231871911793`*^9, 3.570723202025717*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Simplify", "[", 
  RowBox[{"EQ", "-", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"AD", "+", 
       RowBox[{"DD", " ", 
        SuperscriptBox[
         RowBox[{"Cos", "[", "\[Theta]", "]"}], "2"]}]}], ")"}], 
     RowBox[{"Y", "[", 
      RowBox[{"\[Theta]", ",", "\[CurlyPhi]"}], "]"}]}], ")"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.545566398439253*^9, 3.545566500458831*^9}, {
  3.546081221396885*^9, 3.546081228014983*^9}, {3.572207095225183*^9, 
  3.5722071067355003`*^9}, {3.572242369876391*^9, 3.5722423814777927`*^9}}],

Cell[BoxData["0"], "Output",
 CellChangeTimes->{
  3.545566501370377*^9, 3.545569053357416*^9, 3.545569131482978*^9, 
   3.545659941599676*^9, 3.545660204952888*^9, 3.545674460494433*^9, 
   3.5457128153788548`*^9, 3.545717358820207*^9, 3.5459097003796186`*^9, 
   3.545910669331172*^9, 3.546081118460226*^9, 3.546081229105959*^9, 
   3.546085609559991*^9, 3.547118202740391*^9, 3.547521364298243*^9, 
   3.5475325655445232`*^9, 3.5707223708988028`*^9, 3.5707232037818413`*^9, {
   3.572207086580309*^9, 3.5722071074545507`*^9}, {3.572242359554631*^9, 
   3.5722423821814404`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["DD"], "Input",
 CellChangeTimes->{{3.572207115627985*^9, 3.5722071248306313`*^9}}],

Cell[BoxData[
 FractionBox[
  RowBox[{
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "\[ImaginaryI]"}], " ", "t", " ", "\[Omega]"}]], " ", 
   SuperscriptBox["J", "2"], " ", 
   SuperscriptBox["\[Epsilon]a", "2"], " ", "\[Epsilon]p", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", " ", 
         SuperscriptBox["M", "2"]}], "-", 
        RowBox[{"l", " ", 
         RowBox[{"(", 
          RowBox[{"1", "+", "l"}], ")"}], " ", 
         SuperscriptBox["r", "2"]}], "+", 
        RowBox[{"2", " ", "M", " ", "r", " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{"-", "1"}], "+", "l", "+", 
           SuperscriptBox["l", "2"], "+", 
           RowBox[{
            SuperscriptBox["r", "2"], " ", 
            SuperscriptBox["\[Omega]", "2"]}]}], ")"}]}]}], ")"}], " ", 
      RowBox[{
       RowBox[{"\[Psi]", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", "M", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[Psi]", "[", "l", "]"}], "\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}], "+", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", "r", " ", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"\[Psi]", "[", "l", "]"}], "\[Prime]\[Prime]",
           MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}]}], ")"}]}], 
  
  RowBox[{
   SuperscriptBox["M", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
   SuperscriptBox["r", "6"]}]]], "Output",
 CellChangeTimes->{{3.572207116167295*^9, 3.57220712507542*^9}}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Massaging the equation", "Subsubsection",
 CellChangeTimes->{{3.57072322042697*^9, 3.570723225856653*^9}}],

Cell["\<\
We want to write the equation in a nicer form. Let us define some ladder \
operation:\
\>", "Text",
 CellChangeTimes->{{3.570723227796381*^9, 3.570723251059828*^9}, {
  3.570723524047071*^9, 3.5707235310617037`*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rulel", "=", 
   RowBox[{"{", 
    RowBox[{"l", "\[Rule]", "l"}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulelp1", "=", 
   RowBox[{"{", 
    RowBox[{"l", "\[Rule]", 
     RowBox[{"l", "+", "1"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulelm1", "=", 
   RowBox[{"{", 
    RowBox[{"l", "\[Rule]", 
     RowBox[{"l", "-", "1"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulelp2", "=", 
   RowBox[{"{", 
    RowBox[{"l", "\[Rule]", 
     RowBox[{"l", "+", "2"}]}], "}"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"rulelm2", "=", 
   RowBox[{"{", 
    RowBox[{"l", "\[Rule]", 
     RowBox[{"l", "-", "2"}]}], "}"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.5460811587493362`*^9, 3.5460811859239407`*^9}, {
  3.570723505328691*^9, 3.570723533808847*^9}}],

Cell["\<\
This is important. We have used the orthogonality properties of the spherical \
harmonics to separate the angular part. This introduces couplings with \
different harmonic indices $l$. We treat each term separately:\
\>", "Text",
 CellChangeTimes->{{3.570723267194339*^9, 3.570723332648855*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"eqDl", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"AD", "+", " ", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Q", "[", 
         RowBox[{"l", "+", "1"}], "]"}], "2"], 
       RowBox[{"(", 
        RowBox[{"DD", "+", 
         RowBox[{"l", " ", "BtD"}]}], ")"}]}], "+", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"Q", "[", "l", "]"}], "2"], 
       RowBox[{"(", 
        RowBox[{"DD", "-", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"l", "+", "1"}], ")"}], "BtD"}]}], ")"}]}]}], ")"}], "/.", 
    "rulel"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqDlp1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"l", "+", "1"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"AtD", "+", 
        RowBox[{"l", " ", "BD"}]}], ")"}]}], ")"}], "/.", "rulelm1"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqDlm1", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Q", "[", "l", "]"}], 
      RowBox[{"(", 
       RowBox[{"AtD", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}], "BD"}]}], ")"}]}], ")"}], "/.", 
    "rulelp1"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqDlp2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Q", "[", 
       RowBox[{"l", "+", "1"}], "]"}], 
      RowBox[{"Q", "[", 
       RowBox[{"l", "+", "2"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"DD", "+", 
        RowBox[{"l", " ", "BtD"}]}], ")"}]}], ")"}], "/.", "rulelm2"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"eqDlm2", "=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"Q", "[", "l", "]"}], 
      RowBox[{"Q", "[", 
       RowBox[{"l", "-", "1"}], "]"}], 
      RowBox[{"(", 
       RowBox[{"DD", "-", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{"l", "+", "1"}], ")"}], "BtD"}]}], ")"}]}], ")"}], "/.", 
    "rulelp2"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.545578628536224*^9, 3.545578778125188*^9}, {
   3.545578834685429*^9, 3.5455789148837223`*^9}, {3.54557913795332*^9, 
   3.5455791550937147`*^9}, {3.5456276145628033`*^9, 3.545627622214821*^9}, 
   3.545627689399475*^9, 3.5456577486274843`*^9, {3.5460813196724873`*^9, 
   3.5460813532237873`*^9}}],

Cell["\<\
and then sum all contributions with different $l$:\
\>", "Text",
 CellChangeTimes->{{3.570723337281124*^9, 3.570723349451503*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQfD", "=", 
   RowBox[{"Simplify", "[", 
    RowBox[{
    "eqDl", "+", "eqDlm1", "+", "eqDlp1", "+", "eqDlp2", "+", "eqDlm2"}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.545146350109329*^9, 3.54514638323176*^9}, {
   3.545146424547529*^9, 3.54514649241077*^9}, {3.545195461668344*^9, 
   3.545195466388774*^9}, {3.545195568336052*^9, 3.54519558288708*^9}, {
   3.545578515440933*^9, 3.545578581754436*^9}, 3.545578637805006*^9, {
   3.545625400955639*^9, 3.545625412693995*^9}, {3.54562745956052*^9, 
   3.5456274603688383`*^9}, 3.545627557932226*^9, {3.5456275971248426`*^9, 
   3.545627652519208*^9}, 3.5456276907120657`*^9, {3.546081355437662*^9, 
   3.54608136366827*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Solve l+2, l-2:", "Subsubsection",
 CellChangeTimes->{{3.5460814308228283`*^9, 3.546081437919973*^9}}],

Cell[TextData[{
 "Now we solve the field equation not for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Psi]", "l"], " ", "but", " ", "for", " ", 
    RowBox[{
     SubscriptBox["\[Psi]", 
      RowBox[{"l", "\[PlusMinus]", "2"}]], ":"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.5707233797513638`*^9, 3.570723426799165*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{"EQfDlp2", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"EQfD", "/.", 
         RowBox[{"l", "\[Rule]", 
          RowBox[{"l", "+", "2"}]}]}], ")"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Psi]", "[", 
         RowBox[{"l", "+", "2"}], "]"}], "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"EQfDlm2", "=", 
   RowBox[{
    RowBox[{"Solve", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{"EQfD", "/.", 
         RowBox[{"l", "\[Rule]", 
          RowBox[{"l", "-", "2"}]}]}], ")"}], "\[Equal]", "0"}], ",", 
      RowBox[{
       SuperscriptBox[
        RowBox[{"\[Psi]", "[", 
         RowBox[{"l", "-", "2"}], "]"}], "\[Prime]\[Prime]",
        MultilineFunction->None], "[", "r", "]"}]}], "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}], "\[IndentingNewLine]"}], "Input",\

 CellChangeTimes->{{3.546081443984098*^9, 3.5460814676793833`*^9}, {
  3.546081500083864*^9, 3.546081531095234*^9}}],

Cell[TextData[{
 "We substitute the results into the equation for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Psi]", "l"], " ", "and", " ", "expand", " ", "it", " ", 
    "to", " ", "second", " ", 
    RowBox[{"order", ":"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "Text",
 CellChangeTimes->{{3.570723444475485*^9, 3.570723463154875*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQfDF", "=", 
   RowBox[{"FullSimplify", "[", 
    RowBox[{"Normal", "[", 
     RowBox[{"Simplify", "[", 
      RowBox[{"Series", "[", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{
          RowBox[{"EQfD", "/.", "EQfDlp2"}], "/.", "EQfDlm2"}], ")"}], ",", 
        RowBox[{"{", 
         RowBox[{"\[Epsilon]a", ",", "0", ",", "2"}], "}"}]}], "]"}], "]"}], 
     "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.546081534879054*^9, 3.546081618610793*^9}, {
  3.546082736427055*^9, 3.5460827402087107`*^9}}],

Cell["These are the coefficients:", "Text",
 CellChangeTimes->{{3.570723470069298*^9, 3.570723478206215*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     FractionBox[
      SuperscriptBox[
       RowBox[{"f", "[", "r", "]"}], "2"], 
      RowBox[{
       RowBox[{
        RowBox[{"f", "'"}], "[", "r", "]"}], 
       RowBox[{"f", "[", "r", "]"}]}]], 
     FractionBox[
      RowBox[{"Coefficient", "[", 
       RowBox[{"EQfDF", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Psi]", "[", "l", "]"}], "'"}], "[", "r", "]"}]}], "]"}], 
      
      RowBox[{"Coefficient", "[", 
       RowBox[{"EQfDF", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Psi]", "[", "l", "]"}], "''"}], "[", "r", "]"}]}], 
       "]"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]a", ",", "0", ",", "2"}], "}"}]}], "]"}], 
  "]"}], "\[IndentingNewLine]", 
 RowBox[{"Vs", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"f", "[", "r", "]"}], "2"], "1"], 
      FractionBox[
       RowBox[{"Coefficient", "[", 
        RowBox[{"EQfDF", ",", 
         RowBox[{
          RowBox[{"\[Psi]", "[", "l", "]"}], "[", "r", "]"}]}], "]"}], 
       RowBox[{"Coefficient", "[", 
        RowBox[{"EQfDF", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Psi]", "[", "l", "]"}], "''"}], "[", "r", "]"}]}], 
        "]"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]a", ",", "0", ",", "2"}], "}"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Clp2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"f", "[", "r", "]"}], "2"], "1"], 
      FractionBox[
       RowBox[{"Coefficient", "[", 
        RowBox[{"EQfDF", ",", 
         RowBox[{
          RowBox[{"\[Psi]", "[", 
           RowBox[{"l", "+", "2"}], "]"}], "[", "r", "]"}]}], "]"}], 
       RowBox[{"Coefficient", "[", 
        RowBox[{"EQfDF", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Psi]", "[", "l", "]"}], "''"}], "[", "r", "]"}]}], 
        "]"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]a", ",", "0", ",", "2"}], "}"}]}], "]"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{"Clm2", "=", 
  RowBox[{"FullSimplify", "[", 
   RowBox[{"Series", "[", 
    RowBox[{
     RowBox[{
      FractionBox[
       SuperscriptBox[
        RowBox[{"f", "[", "r", "]"}], "2"], "1"], 
      FractionBox[
       RowBox[{"Coefficient", "[", 
        RowBox[{"EQfDF", ",", 
         RowBox[{
          RowBox[{"\[Psi]", "[", 
           RowBox[{"l", "-", "2"}], "]"}], "[", "r", "]"}]}], "]"}], 
       RowBox[{"Coefficient", "[", 
        RowBox[{"EQfDF", ",", 
         RowBox[{
          RowBox[{
           RowBox[{"\[Psi]", "[", "l", "]"}], "''"}], "[", "r", "]"}]}], 
        "]"}]]}], ",", 
     RowBox[{"{", 
      RowBox[{"\[Epsilon]a", ",", "0", ",", "2"}], "}"}]}], "]"}], 
   "]"}]}]}], "Input",
 CellChangeTimes->{{3.5460816210018063`*^9, 3.546081686811599*^9}, {
  3.546081983444722*^9, 3.5460819891530724`*^9}, {3.5460820471227703`*^9, 
  3.54608205064476*^9}, {3.546082085285491*^9, 3.546082143133037*^9}, {
  3.54608677115333*^9, 3.5460867779223423`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"1", "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]a", "]"}], "3"],
    SeriesData[$CellContext`\[Epsilon]a, 0, {}, 0, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Epsilon]a, 0, {1}, 0, 3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.546082096429422*^9, 3.546082143643807*^9}, 
   3.546082756367882*^9, 3.546085631729156*^9, 3.546086732808488*^9, 
   3.546086778429817*^9, 3.547118230784815*^9, 3.547521385585203*^9, 
   3.570722398141121*^9, 3.570723547021879*^9, 3.572207230653226*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["\[AliasDelimiter]"], "Input",
 CellChangeTimes->{{3.572242510892729*^9, 3.572242510936474*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["J", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Mu]", "-", "\[Omega]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Mu]", "+", "\[Omega]"}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"1", "+", "l"}], "]"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{"2", "+", "l"}], "]"}], " ", 
     SuperscriptBox["\[Epsilon]a", "2"]}], 
    RowBox[{
     SuperscriptBox["M", "2"], " ", 
     SuperscriptBox["r", "3"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]a", "]"}], "3"],
    SeriesData[$CellContext`\[Epsilon]a, 0, {}, 2, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Epsilon]a, 
   0, {$CellContext`J^2 $CellContext`M^(-2) (
     2 $CellContext`M - $CellContext`r) $CellContext`r^(-3) ($CellContext`\
\[Mu] - $CellContext`\[Omega]) ($CellContext`\[Mu] + $CellContext`\[Omega]) \
$CellContext`Q[1 + $CellContext`l] $CellContext`Q[2 + $CellContext`l]}, 2, 3, 
   1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.546082096429422*^9, 3.546082143643807*^9}, 
   3.546082756367882*^9, 3.546085631729156*^9, 3.546086732808488*^9, 
   3.546086778429817*^9, 3.547118230784815*^9, 3.547521385585203*^9, 
   3.570722398141121*^9, 3.570723547021879*^9, 3.572207231178595*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   FractionBox[
    RowBox[{
     SuperscriptBox["J", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", " ", "M"}], "-", "r"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Mu]", "-", "\[Omega]"}], ")"}], " ", 
     RowBox[{"(", 
      RowBox[{"\[Mu]", "+", "\[Omega]"}], ")"}], " ", 
     RowBox[{"Q", "[", 
      RowBox[{
       RowBox[{"-", "1"}], "+", "l"}], "]"}], " ", 
     RowBox[{"Q", "[", "l", "]"}], " ", 
     SuperscriptBox["\[Epsilon]a", "2"]}], 
    RowBox[{
     SuperscriptBox["M", "2"], " ", 
     SuperscriptBox["r", "3"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]a", "]"}], "3"],
    SeriesData[$CellContext`\[Epsilon]a, 0, {}, 2, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Epsilon]a, 
   0, {$CellContext`J^2 $CellContext`M^(-2) (
     2 $CellContext`M - $CellContext`r) $CellContext`r^(-3) ($CellContext`\
\[Mu] - $CellContext`\[Omega]) ($CellContext`\[Mu] + $CellContext`\[Omega]) \
$CellContext`Q[-1 + $CellContext`l] $CellContext`Q[$CellContext`l]}, 2, 3, 1],
  
  Editable->False]], "Output",
 CellChangeTimes->{{3.546082096429422*^9, 3.546082143643807*^9}, 
   3.546082756367882*^9, 3.546085631729156*^9, 3.546086732808488*^9, 
   3.546086778429817*^9, 3.547118230784815*^9, 3.547521385585203*^9, 
   3.570722398141121*^9, 3.570723547021879*^9, 3.572207231212749*^9}]
}, Open  ]],

Cell["\<\
This is the final form of the equation:\
\>", "Text",
 CellChangeTimes->{{3.570723558637434*^9, 3.5707235637731123`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"EQF", "=", 
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"f", "[", "r", "]"}], "2"], 
     RowBox[{
      RowBox[{
       RowBox[{"\[Psi]", "[", "l", "]"}], "''"}], "[", "r", "]"}]}], "+", 
    RowBox[{
     RowBox[{
      RowBox[{"f", "'"}], "[", "r", "]"}], 
     RowBox[{"f", "[", "r", "]"}], 
     RowBox[{
      RowBox[{
       RowBox[{"\[Psi]", "[", "l", "]"}], "'"}], "[", "r", "]"}]}], "+", 
    RowBox[{"Vs", " ", 
     RowBox[{
      RowBox[{"\[Psi]", "[", "l", "]"}], "[", "r", "]"}]}], "+", 
    RowBox[{
     FractionBox[
      RowBox[{"f", "[", "r", "]"}], 
      RowBox[{"(", 
       RowBox[{"1", "-", 
        RowBox[{"2", 
         FractionBox["M", "r"]}]}], ")"}]], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Clp2", " ", 
        RowBox[{
         RowBox[{"\[Psi]", "[", 
          RowBox[{"l", "+", "2"}], "]"}], "[", "r", "]"}]}], "+", 
       RowBox[{"Clm2", " ", 
        RowBox[{
         RowBox[{"\[Psi]", "[", 
          RowBox[{"l", "-", "2"}], "]"}], "[", "r", "]"}]}]}], ")"}]}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.546086871045272*^9, 3.5460869414580593`*^9}}],

Cell["\<\
Check: to second order it\[CloseCurlyQuote]s the same as the original one:\
\>", "Text",
 CellChangeTimes->{{3.570723572878067*^9, 3.570723587694373*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FullSimplify", "[", 
  RowBox[{"Series", "[", 
   RowBox[{
    RowBox[{
     FractionBox["EQF", 
      SuperscriptBox[
       RowBox[{"f", "[", "r", "]"}], "2"]], "-", 
     FractionBox["EQfDF", 
      RowBox[{"Coefficient", "[", 
       RowBox[{"EQfDF", ",", 
        RowBox[{
         RowBox[{
          RowBox[{"\[Psi]", "[", "l", "]"}], "''"}], "[", "r", "]"}]}], 
       "]"}]]}], ",", 
    RowBox[{"{", 
     RowBox[{"\[Epsilon]a", ",", "0", ",", "2"}], "}"}]}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.546086945236147*^9, 3.546086986272428*^9}}],

Cell[BoxData[
 InterpretationBox[
  SuperscriptBox[
   RowBox[{"O", "[", "\[Epsilon]a", "]"}], "3"],
  SeriesData[$CellContext`\[Epsilon]a, 0, {}, 3, 3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{3.5460869503828497`*^9, 3.54608698774842*^9, 
  3.547118232227479*^9, 3.547521386929627*^9, 3.5707224058768387`*^9, 
  3.5707235894740868`*^9, 3.5722072618903427`*^9}]
}, Open  ]],

Cell["\<\
Near-horizon expansion of the potential:\
\>", "Text",
 CellChangeTimes->{{3.5707235997638597`*^9, 3.5707236069463863`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Series", "[", 
  RowBox[{
   RowBox[{"Normal", "[", 
    RowBox[{"Simplify", "[", 
     RowBox[{"Series", "[", 
      RowBox[{"Vs", ",", 
       RowBox[{"{", 
        RowBox[{"r", ",", 
         RowBox[{"2", "M", 
          RowBox[{"(", 
           RowBox[{"1", "-", 
            RowBox[{
             SuperscriptBox["J", "2"], 
             FractionBox[
              SuperscriptBox["\[Epsilon]a", "2"], 
              RowBox[{"4", " ", 
               SuperscriptBox["M", "4"]}]]}]}], ")"}]}], ",", "0"}], "}"}]}], 
      "]"}], "]"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"\[Epsilon]a", ",", "0", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.546085629077352*^9, 3.546085711857964*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   SuperscriptBox["\[Omega]", "2"], "-", 
   FractionBox[
    RowBox[{
     RowBox[{"(", 
      RowBox[{"J", " ", "m", " ", "\[Omega]"}], ")"}], " ", "\[Epsilon]a"}], 
    RowBox[{"2", " ", 
     SuperscriptBox["M", "3"]}]], "+", 
   FractionBox[
    RowBox[{
     SuperscriptBox["J", "2"], " ", 
     SuperscriptBox["m", "2"], " ", 
     SuperscriptBox["\[Epsilon]a", "2"]}], 
    RowBox[{"16", " ", 
     SuperscriptBox["M", "6"]}]], "+", 
   InterpretationBox[
    SuperscriptBox[
     RowBox[{"O", "[", "\[Epsilon]a", "]"}], "3"],
    SeriesData[$CellContext`\[Epsilon]a, 0, {}, 0, 3, 1],
    Editable->False]}],
  SeriesData[$CellContext`\[Epsilon]a, 
   0, {$CellContext`\[Omega]^2, 
    Rational[-1, 
      2] $CellContext`J $CellContext`m $CellContext`M^(-3) $CellContext`\
\[Omega], 
    Rational[1, 16] $CellContext`J^2 $CellContext`m^2 $CellContext`M^(-6)}, 0,
    3, 1],
  Editable->False]], "Output",
 CellChangeTimes->{{3.546085632853072*^9, 3.546085712626863*^9}, 
   3.570722706457685*^9, 3.5707236080108423`*^9, 3.5722072830861473`*^9}]
}, Open  ]],

Cell["\<\
If we wish, we can save the final equation, which is now ready to be \
integrated with our preferred method.\
\>", "Text",
 CellChangeTimes->{{3.570723614089432*^9, 3.570723636578874*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"DumpSave", "[", 
   RowBox[{"\"\<eq_scalar_final.mx\>\"", ",", 
    RowBox[{"{", 
     RowBox[{"EQfDF", ",", "Vs", ",", "AD", ",", "DD"}], "}"}]}], "]"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.5460826919963083`*^9, 3.54608275329396*^9}, {
  3.547521383113503*^9, 3.5475213888409986`*^9}, {3.547532599283934*^9, 
  3.5475326004054813`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1280, 712},
WindowMargins->{{0, 0}, {Automatic, 0}},
FrontEndVersion->"8.0 for Linux x86 (64-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 412, 8, 64, "Subtitle"],
Cell[982, 32, 521, 7, 45, "Subtitle"],
Cell[1506, 41, 106, 1, 27, "Text"],
Cell[1615, 44, 11376, 267, 468, "Input"],
Cell[12994, 313, 259, 6, 29, "Text"],
Cell[13256, 321, 173, 4, 28, "Input"],
Cell[13432, 327, 124, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[13581, 334, 2689, 68, 131, "Input"],
Cell[16273, 404, 3660, 104, 170, "Output"],
Cell[19936, 510, 4255, 124, 170, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[24240, 640, 483, 6, 45, "Subtitle"],
Cell[CellGroupData[{
Cell[24748, 650, 4548, 98, 240, "Input"],
Cell[29299, 750, 8501, 231, 208, "Output"]
}, Open  ]],
Cell[37815, 984, 127, 3, 27, "Text"],
Cell[37945, 989, 372, 10, 46, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[38354, 1004, 90, 1, 80, "Title"],
Cell[CellGroupData[{
Cell[38469, 1009, 190, 4, 27, "Subsubsection"],
Cell[38662, 1015, 2896, 77, 344, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[41595, 1097, 307, 6, 27, "Subsubsection"],
Cell[41905, 1105, 23790, 697, 854, "Input"],
Cell[65698, 1804, 3434, 101, 103, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[69169, 1910, 280, 5, 21, "Subsubsection"],
Cell[69452, 1917, 140, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[69617, 1924, 254, 9, 35, "Input"],
Cell[69874, 1935, 7847, 208, 201, "Output"]
}, Open  ]],
Cell[77736, 2146, 158, 3, 27, "Text"],
Cell[77897, 2151, 3044, 80, 176, "Input"],
Cell[80944, 2233, 205, 4, 27, "Text"],
Cell[CellGroupData[{
Cell[81174, 2241, 2541, 70, 196, "Input"],
Cell[83718, 2313, 301, 5, 21, "Print"],
Cell[84022, 2320, 295, 5, 28, "Output"],
Cell[84320, 2327, 296, 5, 28, "Output"],
Cell[84619, 2334, 296, 5, 28, "Output"]
}, Open  ]],
Cell[84930, 2342, 152, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[85107, 2349, 858, 21, 114, "Input"],
Cell[85968, 2372, 341, 6, 28, "Output"]
}, Open  ]],
Cell[86324, 2381, 179, 4, 27, "Text"],
Cell[CellGroupData[{
Cell[86528, 2389, 578, 15, 35, "Input"],
Cell[87109, 2406, 581, 9, 28, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87727, 2420, 96, 1, 28, "Input"],
Cell[87826, 2423, 1892, 56, 55, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[89767, 2485, 112, 1, 27, "Subsubsection"],
Cell[89882, 2488, 226, 5, 27, "Text"],
Cell[90111, 2495, 867, 26, 97, "Input"],
Cell[90981, 2523, 305, 5, 43, "Text"],
Cell[91289, 2530, 2322, 76, 103, "Input"],
Cell[93614, 2608, 140, 3, 27, "Text"],
Cell[93757, 2613, 723, 14, 28, "Input"]
}, Open  ]],
Cell[CellGroupData[{
Cell[94517, 2632, 108, 1, 27, "Subsubsection"],
Cell[94628, 2635, 387, 11, 30, "Text"],
Cell[95018, 2648, 1199, 35, 70, "Input"],
Cell[96220, 2685, 374, 10, 30, "Text"],
Cell[96597, 2697, 558, 15, 28, "Input"],
Cell[97158, 2714, 109, 1, 27, "Text"],
Cell[CellGroupData[{
Cell[97292, 2719, 3239, 99, 226, "Input"],
Cell[100534, 2820, 593, 13, 32, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[101164, 2838, 109, 1, 28, InheritFromParent],
Cell[101276, 2841, 1427, 36, 53, "Output"],
Cell[102706, 2879, 1419, 36, 53, "Output"]
}, Open  ]],
Cell[104140, 2918, 131, 3, 27, "Text"],
Cell[104274, 2923, 1157, 38, 68, "Input"],
Cell[105434, 2963, 164, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[105623, 2970, 585, 18, 59, "Input"],
Cell[106211, 2990, 374, 8, 32, "Output"]
}, Open  ]],
Cell[106600, 3001, 134, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[106759, 3008, 732, 21, 62, "Input"],
Cell[107494, 3031, 1098, 31, 53, "Output"]
}, Open  ]],
Cell[108607, 3065, 198, 4, 27, "Text"],
Cell[108808, 3071, 378, 9, 28, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
